@@ -149,12 +149,8 @@ static void _add_results_in_menu (GldiModuleInstance *myApplet)
 	{
 		gtk_widget_hide (s_pLaunchCommand);
 		// if there are results and no selection, select the first entry
-		#if (GTK_MAJOR_VERSION > 2)
 		GtkWidget *pMenuItem = gtk_menu_shell_get_selected_item (
 			GTK_MENU_SHELL (myData.pMenu));
-		#else
-		GtkWidget *pMenuItem = gtk_menu_get_active (GTK_MENU (myData.pMenu));
-		#endif
 		if (pMenuItem == NULL || pMenuItem == s_pLaunchCommand)
 			gtk_menu_shell_select_item (GTK_MENU_SHELL (myData.pMenu),
 				((EntryInfo *)s_pEntries->data)->pMenuItem);
@@ -365,11 +361,7 @@ static GtkWidget *s_pEntryContainer = NULL;
 
 static void _launch_app_of_selected_item (GtkWidget *pMenu)
 {
-	#if (GTK_MAJOR_VERSION > 2)
 	GtkWidget *pMenuItem = gtk_menu_shell_get_selected_item (GTK_MENU_SHELL (pMenu));
-	#else
-	GtkWidget *pMenuItem = gtk_menu_get_active (GTK_MENU (pMenu));
-	#endif
 
 	if (pMenuItem == s_pEntryContainer) // 'entry' selected
 		pMenuItem = ((EntryInfo *)s_pEntries->data)->pMenuItem; // select the first item
@@ -390,8 +382,13 @@ static void _launch_app_of_selected_item (GtkWidget *pMenu)
 static gboolean _on_key_pressed_menu (GtkWidget *pMenu, GdkEventKey *pEvent,
 	GldiModuleInstance *myApplet)
 {
-	// redirect the signal to the entry
+	/* redirect the signal to the entry:
+	 * with GTK 3.10, it seems that this redirection is no longer needed and
+	 * cause a bug: each character is doubled...
+	 */
+	#if ! GTK_CHECK_VERSION (3, 10, 0)
 	g_signal_emit_by_name (myData.pEntry, "key-press-event", pEvent, myApplet);
+	#endif
 
 	if (s_pOtherEntries != NULL)
 	{
@@ -428,7 +425,7 @@ static gboolean _on_button_release_launch_command (G_GNUC_UNUSED GtkWidget *pMen
 void cd_menu_append_entry (void)
 {
 	// menu item at the top of the menu with a GtkImage and a GtkEntry
-	GtkWidget *pMenuItem = gldi_menu_item_new_full (NULL, GTK_STOCK_EXECUTE, FALSE, GTK_ICON_SIZE_LARGE_TOOLBAR);
+	GtkWidget *pMenuItem = gldi_menu_item_new_full (NULL, GLDI_ICON_NAME_EXECUTE, FALSE, GTK_ICON_SIZE_LARGE_TOOLBAR);
 	
 	GtkWidget *pEntry = gtk_entry_new ();
 	gtk_container_add (GTK_CONTAINER (pMenuItem), pEntry);
@@ -456,7 +453,7 @@ void cd_menu_append_entry (void)
 	gtk_menu_shell_append (GTK_MENU_SHELL (myData.pMenu), pMenuItem);
 
 	// Launch this command (create the widget but we don't insert it now)
-	s_pLaunchCommand = gldi_menu_item_new_full (D_("Launch this command"), GTK_STOCK_EXECUTE, FALSE, GTK_ICON_SIZE_LARGE_TOOLBAR);
+	s_pLaunchCommand = gldi_menu_item_new_full (D_("Launch this command"), GLDI_ICON_NAME_EXECUTE, FALSE, GTK_ICON_SIZE_LARGE_TOOLBAR);
 	g_signal_connect (s_pLaunchCommand, "button-release-event",
 		G_CALLBACK (_on_button_release_launch_command), NULL);
 	g_object_ref (s_pLaunchCommand);
