@@ -32,10 +32,23 @@ void cd_trigger_search (void)
 {
 	if (myData.pDialog == NULL)
 		return;
+
+	static CDEventType iOldCategory = -1;
+
 	const gchar *cQuery = gtk_entry_get_text (GTK_ENTRY (myData.pEntry));
 	CDEventType iCategory = myData.iCurrentCaterogy;
 	GtkListStore *pModel = myData.pModel;
-	
+
+	/* avoid rebuild when pressing "non letter" keys
+	 * Note: cQuery's pointer is not automatically modified when the string change.
+	 */
+	if (iOldCategory == iCategory && g_strcmp0 (myData.cQuery, cQuery) == 0)
+		return;
+
+	g_free (myData.cQuery);
+	myData.cQuery = g_strdup (cQuery);
+	iOldCategory = iCategory;
+
 	int iSortType = 0;
 	if (iCategory >= CD_EVENT_TOP_RESULTS)
 	{
@@ -59,18 +72,23 @@ static void on_click_category_button (GtkButton *button, gpointer data)
 	cd_trigger_search ();
 }
 
-#if (GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION >= 16)
 static void on_clear_filter (GtkEntry *pEntry, GtkEntryIconPosition icon_pos, GdkEvent *event, gpointer data)
 {
 	gtk_entry_set_text (pEntry, "");
 	cd_debug ("relaunch the search...");
 	cd_trigger_search ();
 }
-#endif
 
-static void on_activate_filter (GtkEntry *pEntry, gpointer data)
+static gboolean on_key_press_filter (G_GNUC_UNUSED GtkWidget *pWidget,
+	GdkEventKey *pKey, G_GNUC_UNUSED gpointer data)
 {
+	if (pKey->keyval == GDK_KEY_Escape)
+	{
+		cd_toggle_dialog ();
+		return TRUE;
+	}
 	cd_trigger_search ();
+	return FALSE;
 }
 
 static void _on_got_events (ZeitgeistResultSet *pEvents, GtkListStore *pModel)
@@ -92,7 +110,11 @@ static void _on_got_events (ZeitgeistResultSet *pEvents, GtkListStore *pModel)
 	//\_____________ parse all the events.
 	while (zeitgeist_result_set_has_next (pEvents))
 	{
+		#ifdef ZEITGEIST_1_0
 		event = zeitgeist_result_set_next (pEvents);
+		#else
+		event = zeitgeist_result_set_next_value (pEvents);
+		#endif
 		iTimeStamp = zeitgeist_event_get_timestamp (event) / 1e3;
 		id = zeitgeist_event_get_id (event);
 		n = zeitgeist_event_num_subjects (event);
@@ -180,7 +202,7 @@ static void _on_got_events (ZeitgeistResultSet *pEvents, GtkListStore *pModel)
 	g_hash_table_destroy (pHashTable);
 }
 
-void cd_folders_free_apps_list (CairoDockModuleInstance *myApplet)
+void cd_folders_free_apps_list (GldiModuleInstance *myApplet)
 {
 	if (myData.pAppList != NULL)
 	{
@@ -258,7 +280,7 @@ static gboolean _on_click_module_tree_view (GtkTreeView *pTreeView, GdkEventButt
 		}
 		else  // right-click
 		{
-			GtkWidget *pMenu = gtk_menu_new ();
+			GtkWidget *pMenu = gldi_menu_new (NULL);
 			g_free (myData.cCurrentUri);
 			myData.cCurrentUri = cUri;
 			
@@ -267,7 +289,7 @@ static gboolean _on_click_module_tree_view (GtkTreeView *pTreeView, GdkEventButt
 				GList *pApps = cairo_dock_fm_list_apps_for_file (cUri);
 				if (pApps != NULL)
 				{
-					GtkWidget *pSubMenu = CD_APPLET_ADD_SUB_MENU_WITH_IMAGE (D_("Open with"), pMenu, GTK_STOCK_OPEN);
+					GtkWidget *pSubMenu = CD_APPLET_ADD_SUB_MENU_WITH_IMAGE (D_("Open with"), pMenu, GLDI_ICON_NAME_OPEN);
 					
 					cd_folders_free_apps_list (myApplet);
 					
@@ -280,7 +302,7 @@ static gboolean _on_click_module_tree_view (GtkTreeView *pTreeView, GdkEventButt
 						myData.pAppList = g_list_prepend (myData.pAppList, pAppInfo[1]);
 						
 						if (pAppInfo[2] != NULL)
-							cIconPath = cairo_dock_search_icon_s_path (pAppInfo[2], cairo_dock_search_icon_size (GTK_ICON_SIZE_LARGE_TOOLBAR));
+							cIconPath = cairo_dock_search_icon_s_path (pAppInfo[2], cairo_dock_search_icon_size (GTK_ICON_SIZE_MENU));
 						else
 							cIconPath = NULL;
 						CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (pAppInfo[0], cIconPath, _cd_launch_with, pSubMenu, pAppInfo[1]);
@@ -291,12 +313,12 @@ static gboolean _on_click_module_tree_view (GtkTreeView *pTreeView, GdkEventButt
 					}
 					g_list_free (pApps);
 				}
-				CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (D_("Open parent folder"), GTK_STOCK_DIRECTORY, _cd_open_parent, pMenu, NULL);
+				CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (D_("Open parent folder"), GLDI_ICON_NAME_DIRECTORY, _cd_open_parent, pMenu, NULL);
 				
-				CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (D_("Copy the location"), GTK_STOCK_COPY, _cd_copy_location, pMenu, NULL);
+				CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (D_("Copy the location"), GLDI_ICON_NAME_COPY, _cd_copy_location, pMenu, NULL);
 			}
 			
-			CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (D_("Delete this event"), GTK_STOCK_REMOVE, _cd_delete_event, pMenu, GUINT_TO_POINTER (id));
+			CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (D_("Delete this event"), GLDI_ICON_NAME_REMOVE, _cd_delete_event, pMenu, GUINT_TO_POINTER (id));
 			
 			gtk_widget_show_all (pMenu);
 			gtk_menu_popup (GTK_MENU (pMenu),
@@ -360,45 +382,55 @@ static inline GtkToolItem *_add_category_button (GtkWidget *pToolBar, const gcha
 #define MARGIN 3
 static GtkWidget *cd_build_events_widget (void)
 {
-	GtkWidget *pMainBox = _gtk_vbox_new (MARGIN);
+	GtkWidget *pMainBox = gtk_box_new (GTK_ORIENTATION_VERTICAL, MARGIN);
 	
 	// category toolbar.
 	GtkWidget *pToolBar = gtk_toolbar_new ();
 	///gtk_toolbar_set_orientation (GTK_TOOLBAR (pToolBar), GTK_ORIENTATION_HORIZONTAL);
 	gtk_toolbar_set_style (GTK_TOOLBAR (pToolBar), GTK_TOOLBAR_BOTH);  // overwrite system preference (GTK_TOOLBAR_ICONS)
+
+	gtk_style_context_add_class (gtk_widget_get_style_context (pToolBar),
+		GTK_STYLE_CLASS_INLINE_TOOLBAR); // style: inline
+	GtkCssProvider *css = gtk_css_provider_new (); // but without border
+	gtk_css_provider_load_from_data (css, ".inline-toolbar.toolbar { "
+		"background: transparent; border-color: transparent; }", -1, NULL);
+	GtkStyleContext *ctx = gtk_widget_get_style_context (pToolBar);
+	gtk_style_context_add_provider (ctx, GTK_STYLE_PROVIDER (css),
+		GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+
 	gtk_toolbar_set_show_arrow (GTK_TOOLBAR (pToolBar), FALSE);  // force to display all the entries.
 	gtk_box_pack_start (GTK_BOX (pMainBox), pToolBar, TRUE, TRUE, MARGIN);
 	
 	int i = 0;
 	GtkToolItem *group = _add_category_button (pToolBar, D_("All"), "stock_search", i++, NULL);
 	_add_category_button (pToolBar, D_("Applications"), "exec", i++, group);
-	_add_category_button (pToolBar, D_("Document"), "document", i++, group);
-	///_add_category_button (pToolBar, D_("Folder"), "folder", i++, group);
-	_add_category_button (pToolBar, D_("Image"), "image", i++, group);
+	_add_category_button (pToolBar, D_("Documents"), "document", i++, group);
+	///_add_category_button (pToolBar, D_("Folders"), "folder", i++, group);
+	_add_category_button (pToolBar, D_("Images"), "image", i++, group);
 	_add_category_button (pToolBar, D_("Audio"), "sound", i++, group);
-	_add_category_button (pToolBar, D_("Video"), "video", i++, group);
+	_add_category_button (pToolBar, D_("Videos"), "video", i++, group);
 	_add_category_button (pToolBar, D_("Web"), "text-html", i++, group);
-	_add_category_button (pToolBar, D_("Other"), "unknown", i++, group);
-	_add_category_button (pToolBar, D_("Top Results"), "gtk-about", i++, group);
+	_add_category_button (pToolBar, D_("Others"), "unknown", i++, group);
+	_add_category_button (pToolBar, D_("Top Results"), "gtk-about", i, group);
 	
 	// search entry.
-	GtkWidget *pFilterBox = _gtk_hbox_new (CAIRO_DOCK_GUI_MARGIN);
+	GtkWidget *pFilterBox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, CAIRO_DOCK_GUI_MARGIN);
 	gtk_box_pack_start (GTK_BOX (pMainBox), pFilterBox, FALSE, FALSE, MARGIN);
 	
 	GtkWidget *pFilterLabel = gtk_label_new (D_("Look for events"));
-	cairo_dock_set_dialog_widget_text_color (GTK_WIDGET (pFilterLabel));
+	gldi_dialog_set_widget_text_color (GTK_WIDGET (pFilterLabel));
 	gtk_box_pack_start (GTK_BOX (pFilterBox), pFilterLabel, FALSE, FALSE, MARGIN);
 	
 	GtkWidget *pEntry = gtk_entry_new ();
-	g_signal_connect (pEntry, "activate", G_CALLBACK (on_activate_filter), NULL);
-	gtk_box_pack_start (GTK_BOX (pFilterBox), pEntry, FALSE, FALSE, MARGIN);
-	gtk_widget_set_tooltip_text (pEntry, "The default boolean operator is AND. Thus the query foo bar will be interpreted as foo AND bar. To exclude a term from the result set prepend it with a minus sign - eg foo -bar. Phrase queries can be done by double quoting the string \"foo is a bar\". You can truncate terms by appending a *. ");
-	
-	#if (GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION >= 16)
+	// press any key:
+	g_signal_connect (pEntry, "key-release-event", G_CALLBACK (on_key_press_filter), NULL);
+	gtk_box_pack_start (GTK_BOX (pFilterBox), pEntry, TRUE, TRUE, MARGIN);
+	gtk_widget_set_tooltip_text (pEntry, D_("The default boolean operator is AND. Thus the query foo bar will be interpreted as foo AND bar. To exclude a term from the result set prepend it with a minus sign - eg foo -bar. Phrase queries can be done by double quoting the string \"foo is a bar\". You can truncate terms by appending a *. "));
+
 	gtk_entry_set_icon_activatable (GTK_ENTRY (pEntry), GTK_ENTRY_ICON_SECONDARY, TRUE);
-	gtk_entry_set_icon_from_stock (GTK_ENTRY (pEntry), GTK_ENTRY_ICON_SECONDARY, GTK_STOCK_CLEAR);
+	gtk_entry_set_icon_from_icon_name (GTK_ENTRY (pEntry), GTK_ENTRY_ICON_SECONDARY, GLDI_ICON_NAME_CLEAR);
 	g_signal_connect (pEntry, "icon-press", G_CALLBACK (on_clear_filter), NULL);
-	#endif
+
 	myData.pEntry = pEntry;
 	gtk_widget_grab_focus (pEntry);
 	
@@ -435,36 +467,36 @@ static GtkWidget *cd_build_events_widget (void)
 	gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (pOneWidget), -1, NULL, rend, "pixbuf", CD_MODEL_ICON, NULL);
 	// file name
 	rend = gtk_cell_renderer_text_new ();
-	col = gtk_tree_view_column_new_with_attributes (_("File name"), rend, "text", CD_MODEL_NAME, NULL);
+	col = gtk_tree_view_column_new_with_attributes (D_("File name"), rend, "text", CD_MODEL_NAME, NULL);
 	gtk_tree_view_column_set_min_width (col, 200);
-	gtk_tree_view_column_set_max_width (col, MAX (500, g_desktopGeometry.iScreenWidth[CAIRO_DOCK_HORIZONTAL]*.67));
+	gtk_tree_view_column_set_max_width (col, MAX (500, g_desktopGeometry.Xscreen.width / g_desktopGeometry.iNbScreens * .67));  // we don't know on which screen is place the container...
 	gtk_tree_view_column_set_sort_column_id (col, CD_MODEL_NAME);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (pOneWidget), col);
 	// date
 	rend = gtk_cell_renderer_text_new ();
-	col = gtk_tree_view_column_new_with_attributes (_("Last access"), rend, "text", CD_MODEL_DATE, NULL);
+	col = gtk_tree_view_column_new_with_attributes (D_("Last access"), rend, "text", CD_MODEL_DATE, NULL);
 	gtk_tree_view_column_set_cell_data_func (col, rend, (GtkTreeCellDataFunc)_render_date, NULL, NULL);
 	gtk_tree_view_column_set_sort_column_id (col, CD_MODEL_DATE);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (pOneWidget), col);
 	
 	// barres de defilement
-	#if (GTK_MAJOR_VERSION < 3)
-	GtkObject *adj = gtk_adjustment_new (0., 0., 100., 1, 10, 10);
-	gtk_tree_view_set_vadjustment (GTK_TREE_VIEW (pOneWidget), GTK_ADJUSTMENT (adj));
-	#else
 	GtkAdjustment *adj = gtk_adjustment_new (0., 0., 100., 1, 10, 10);
 	gtk_scrollable_set_vadjustment (GTK_SCROLLABLE (pOneWidget), GTK_ADJUSTMENT (adj));
-	#endif
+
 	GtkWidget *pScrolledWindow = gtk_scrolled_window_new (NULL, NULL);
 	g_object_set (pScrolledWindow, "height-request", 300, NULL);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (pScrolledWindow), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+	#if GTK_CHECK_VERSION (3, 8, 0)
+	gtk_container_add (GTK_CONTAINER (pScrolledWindow), pOneWidget);
+	#else
 	gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (pScrolledWindow), pOneWidget);
+	#endif
 	gtk_box_pack_start (GTK_BOX (pMainBox), pScrolledWindow, FALSE, FALSE, MARGIN);
 
 	return pMainBox;
 }
 
-static void _on_dialog_destroyed (CairoDockModuleInstance *myApplet)
+static void _on_dialog_destroyed (GldiModuleInstance *myApplet)
 {
 	myData.pDialog = NULL;
 	myData.pEntry = NULL;  // interactive widget inside the dialog are destroyed with it.
@@ -474,6 +506,7 @@ static void _on_dialog_destroyed (CairoDockModuleInstance *myApplet)
 static gboolean _show_dialog_delayed (gpointer data)
 {
 	cd_toggle_dialog ();
+	#ifdef ZEITGEIST_1_0
 	if (myData.pDialog != NULL)  // dialog built with success, quit.
 	{
 		myData.iSidTryDialog = 0;
@@ -485,19 +518,20 @@ static gboolean _show_dialog_delayed (gpointer data)
 		cd_debug (" %d tries", myData.iNbTries);
 		if (myData.iNbTries >= 3)  // definitely no hope -> show a message to the user.
 		{
-			cairo_dock_remove_dialog_if_any (myIcon);
-			cairo_dock_show_temporary_dialog_with_icon (D_("You need to install the Zeitgeist data engine."), myIcon, myContainer, 6000, "same icon");
+			gldi_dialogs_remove_on_icon (myIcon);
+			gldi_dialog_show_temporary_with_icon (D_("You need to install the Zeitgeist data engine."), myIcon, myContainer, 6000, "same icon");
 			myData.iSidTryDialog = 0;
 			return FALSE;
 		}
 	}
+	#endif
 	return TRUE;
 }
 void cd_toggle_dialog (void)
 {
 	if (myData.pDialog != NULL)  // the dialog can be opened in the case it was called from the shortkey.
 	{
-		cairo_dock_dialog_unreference (myData.pDialog);
+		gldi_object_unref (GLDI_OBJECT(myData.pDialog));
 		myData.pDialog = NULL;
 	}
 	else
@@ -508,6 +542,7 @@ void cd_toggle_dialog (void)
 			cd_debug ("first search");
 			myData.pLog = zeitgeist_log_new ();  // may launch the Zeitgeist daemon if it's not yet running.
 		}
+		#ifdef ZEITGEIST_1_0
 		if (! zeitgeist_log_is_connected (myData.pLog))
 		{
 			cd_debug ("not yet connected");
@@ -518,10 +553,21 @@ void cd_toggle_dialog (void)
 			}
 			return;
 		}
-		
+		#else
+		gboolean bIsConnected;
+		g_object_get (G_OBJECT (myData.pLog), "is-connected", &bIsConnected, NULL);
+		if (! bIsConnected)
+		{
+			// will retry when it will be connected
+			g_signal_connect (myData.pLog, "notify::is-connected",
+				G_CALLBACK (_show_dialog_delayed), NULL);
+			return;
+		}
+		#endif
+
 		// build the dialog and the tree model.
 		GtkWidget *pInteractiveWidget = cd_build_events_widget ();
-		myData.pDialog = cairo_dock_show_dialog_full (D_("Browse and search in recent events"),
+		myData.pDialog = gldi_dialog_show (D_("Browse and search in recent events"),
 			myIcon,
 			myContainer,
 			0,
