@@ -116,7 +116,7 @@ static void cd_compute_size (CairoDock *pDock)
 	pDock->iMaxDockWidth = pDock->fFlatDockWidth = pDock->iMinDockWidth = MAX (W, x);  // if > W, we'll come back here with a smaller ratio.
 	//g_print ("iMaxDockWidth : %d (%.2f)\n", pDock->iMaxDockWidth, pDock->container.fRatio);
 	
-	pDock->iMaxDockHeight = myDocksParam.iDockLineWidth + myDocksParam.iFrameMargin + hicon * pDock->container.fRatio + myDocksParam.iFrameMargin + myDocksParam.iDockLineWidth + (pDock->container.bIsHorizontal || !myIconsParam.bTextAlwaysHorizontal ? myIconsParam.iLabelSize : 0);
+	pDock->iMaxDockHeight = myDocksParam.iDockLineWidth + myDocksParam.iFrameMargin + hicon * pDock->container.fRatio + myDocksParam.iFrameMargin + myDocksParam.iDockLineWidth + (pDock->container.bIsHorizontal ? myIconsParam.iLabelSize : 0);
 	
 	pDock->iMaxDockHeight = MAX (pDock->iMaxDockHeight, pDock->iMaxIconHeight * (1 + myIconsParam.fAmplitude));  // au moins la taille du FBO.
 	//g_print ("panel view: pDock->iMaxIconHeight = %d\n", pDock->iMaxIconHeight);
@@ -126,7 +126,7 @@ static void cd_compute_size (CairoDock *pDock)
 	
 	pDock->iActiveWidth = pDock->iMaxDockWidth;
 	pDock->iActiveHeight = pDock->iMinDockHeight;
-	if (! pDock->container.bIsHorizontal && myIconsParam.bTextAlwaysHorizontal)
+	if (! pDock->container.bIsHorizontal)
 		pDock->iMaxDockHeight += 8*myIconsParam.iLabelSize;  // vertical dock, add some padding to draw the labels
 	
 	CDPanelData *pData = pDock->pRendererData;
@@ -186,7 +186,10 @@ static void cd_render (cairo_t *pCairoContext, CairoDock *pDock)
 	if (fLineWidth > 0)
 	{
 		cairo_set_line_width (pCairoContext, fLineWidth);
-		cairo_set_source_rgba (pCairoContext, myDocksParam.fLineColor[0], myDocksParam.fLineColor[1], myDocksParam.fLineColor[2], myDocksParam.fLineColor[3]);
+		if (myDocksParam.bUseDefaultColors)
+			gldi_style_colors_set_line_color (pCairoContext);
+		else
+			gldi_color_set_cairo (pCairoContext, &myDocksParam.fLineColor);
 		cairo_stroke (pCairoContext);
 	}
 	else
@@ -277,7 +280,10 @@ static void cd_render (cairo_t *pCairoContext, CairoDock *pDock)
 					
 					cairo_set_operator (pCairoContext, CAIRO_OPERATOR_OVER);
 					cairo_set_line_width (pCairoContext, fLineWidth);
-					cairo_set_source_rgba (pCairoContext, myDocksParam.fLineColor[0], myDocksParam.fLineColor[1], myDocksParam.fLineColor[2], myDocksParam.fLineColor[3]);
+					if (myDocksParam.bUseDefaultColors)
+						gldi_style_colors_set_line_color (pCairoContext);
+					else
+						gldi_color_set_cairo (pCairoContext, &myDocksParam.fLineColor);
 					cairo_stroke (pCairoContext);
 				}
 			}
@@ -358,34 +364,31 @@ static void cd_render_optimized (cairo_t *pCairoContext, CairoDock *pDock, GdkRe
 	
 	//\____________________ On dessine la partie du cadre qui va bien.
 	cairo_new_path (pCairoContext);
-
+	if (myDocksParam.bUseDefaultColors)
+		gldi_style_colors_set_line_color (pCairoContext);
+	else
+		gldi_color_set_cairo (pCairoContext, &myDocksParam.fLineColor);
+	cairo_set_line_width (pCairoContext, fLineWidth);
+	
 	if (pDock->container.bIsHorizontal)
 	{
 		cairo_move_to (pCairoContext, fDockOffsetX, fDockOffsetY - fLineWidth / 2);
 		cairo_rel_line_to (pCairoContext, pArea->width, 0);
-		cairo_set_line_width (pCairoContext, fLineWidth);
-		cairo_set_source_rgba (pCairoContext, myDocksParam.fLineColor[0], myDocksParam.fLineColor[1], myDocksParam.fLineColor[2], myDocksParam.fLineColor[3]);
 		cairo_stroke (pCairoContext);
 
 		cairo_new_path (pCairoContext);
 		cairo_move_to (pCairoContext, fDockOffsetX, (pDock->container.bDirectionUp ? iHeight - fLineWidth / 2 : pDock->iDecorationsHeight + 1.5 * fLineWidth));
 		cairo_rel_line_to (pCairoContext, pArea->width, 0);
-		cairo_set_line_width (pCairoContext, fLineWidth);
-		cairo_set_source_rgba (pCairoContext, myDocksParam.fLineColor[0], myDocksParam.fLineColor[1], myDocksParam.fLineColor[2], myDocksParam.fLineColor[3]);
 	}
 	else
 	{
 		cairo_move_to (pCairoContext, fDockOffsetX - fLineWidth / 2, fDockOffsetY);
 		cairo_rel_line_to (pCairoContext, 0, pArea->height);
-		cairo_set_line_width (pCairoContext, fLineWidth);
-		cairo_set_source_rgba (pCairoContext, myDocksParam.fLineColor[0], myDocksParam.fLineColor[1], myDocksParam.fLineColor[2], myDocksParam.fLineColor[3]);
 		cairo_stroke (pCairoContext);
 
 		cairo_new_path (pCairoContext);
 		cairo_move_to (pCairoContext, (pDock->container.bDirectionUp ? iHeight - fLineWidth / 2 : pDock->iDecorationsHeight + 1.5 * fLineWidth), fDockOffsetY);
 		cairo_rel_line_to (pCairoContext, 0, pArea->height);
-		cairo_set_line_width (pCairoContext, fLineWidth);
-		cairo_set_source_rgba (pCairoContext, myDocksParam.fLineColor[0], myDocksParam.fLineColor[1], myDocksParam.fLineColor[2], myDocksParam.fLineColor[3]);
 	}
 	cairo_stroke (pCairoContext);
 
@@ -483,7 +486,10 @@ static void cd_render_opengl (CairoDock *pDock)
 	if (fLineWidth != 0)
 	{
 		glLineWidth (fLineWidth);
-		glColor4f (myDocksParam.fLineColor[0], myDocksParam.fLineColor[1], myDocksParam.fLineColor[2], myDocksParam.fLineColor[3]);
+		if (myDocksParam.bUseDefaultColors)
+			gldi_style_colors_set_line_color (NULL);
+		else
+			gldi_color_set_opengl (&myDocksParam.fLineColor);
 		cairo_dock_stroke_gl_path (pFramePath, TRUE);
 	}
 	glPopMatrix ();
@@ -559,7 +565,10 @@ static void cd_render_opengl (CairoDock *pDock)
 						delta - dx, h_,
 						delta, h_);
 					glLineWidth (fLineWidth);
-					glColor4f (myDocksParam.fLineColor[0], myDocksParam.fLineColor[1], myDocksParam.fLineColor[2], myDocksParam.fLineColor[3]);
+					if (myDocksParam.bUseDefaultColors)
+						gldi_style_colors_set_line_color (NULL);
+					else
+						gldi_color_set_opengl (&myDocksParam.fLineColor);
 					cairo_dock_stroke_gl_path (pPath, FALSE);
 				}
 				
@@ -743,88 +752,97 @@ static void cd_update_input_shape (CairoDock *pDock)
 	{
 		CDPanelData *pData = pDock->pRendererData;
 		g_return_if_fail (pData != NULL);
-		
+
 		gboolean bValidGroup = FALSE;  // valid = non-empty
-		#if (GTK_MAJOR_VERSION < 3)
-		cairo_t *pCairoContext = gdk_cairo_create (pDock->pShapeBitmap);
-		if  (pCairoContext != NULL)
-		{
-			cairo_set_source_rgba (pCairoContext, 0.0f, 0.0f, 0.0f, 0.0f);
-			cairo_set_operator (pCairoContext, CAIRO_OPERATOR_SOURCE);
-			
-			GList *ic;
-			Icon *pIcon;
-			for (ic = pDock->icons; ic != NULL; ic = ic->next)
-			{
-				pIcon = ic->data;
-				if (CAIRO_DOCK_ICON_TYPE_IS_SEPARATOR (pIcon))
-				{
-					if (bValidGroup)
-					{
-						if (pDock->container.bIsHorizontal)
-						{
-							cairo_rectangle (pCairoContext,
-								pIcon->fXAtRest + 2 * my_fPanelRadius,  // we let a few pixels to be able to grab the separtator, and to avoid leaving the dock too easily.
-								0,
-								pData->fGroupGap - 4 * my_fPanelRadius,
-								pDock->iMaxDockHeight);  // we use iMaxDockHeight instead of the actual window size, because at this time, the dock's window may not have its definite size.
-						}
-						else
-						{
-							cairo_rectangle (pCairoContext,
-								0,
-								pIcon->fXAtRest + 2 * my_fPanelRadius,  // we let a few pixels to be able to grab the separtator, and to avoid leaving the dock too easily.
-								pDock->iMaxDockHeight,
-								pData->fGroupGap - 4 * my_fPanelRadius);
-						}
-						cairo_fill (pCairoContext);
-						bValidGroup = FALSE;
-					}
-				}
-				else
-				{
-					bValidGroup = TRUE;
-				}
-			}
-			
-			cairo_destroy (pCairoContext);
-		}
-		#else
+		gboolean bHasGroups = FALSE;
+		double xi;
+		double w = pData->fGroupGap - 4 * my_fPanelRadius;  // all groups have the same width
+		double h = pDock->iMaxDockHeight;  // we use iMaxDockHeight instead of the actual window size, because at this time, the dock's window may not have its definite size.
 		cairo_rectangle_int_t rect;
+
 		GList *ic;
-			Icon *pIcon;
-			for (ic = pDock->icons; ic != NULL; ic = ic->next)
+		Icon *pIcon;
+		for (ic = pDock->icons; ic != NULL; ic = ic->next)
+		{
+			pIcon = ic->data;
+			if (CAIRO_DOCK_ICON_TYPE_IS_SEPARATOR (pIcon))
 			{
-				pIcon = ic->data;
-				if (CAIRO_DOCK_ICON_TYPE_IS_SEPARATOR (pIcon))
+				if (bValidGroup)
 				{
-					if (bValidGroup)
+					xi = pIcon->fXAtRest + 2 * my_fPanelRadius;  // we let a few pixels to be able to grab the separtator, and to avoid leaving the dock too easily.
+					if (pDock->container.bIsHorizontal)
 					{
-						if (pDock->container.bIsHorizontal)
-						{
-							rect.x = pIcon->fXAtRest + 2 * my_fPanelRadius;  // we let a few pixels to be able to grab the separtator, and to avoid leaving the dock too easily.
-							rect.y = 0;
-							rect.width = pData->fGroupGap - 4 * my_fPanelRadius;
-							rect.height = pDock->iMaxDockHeight;  // we use iMaxDockHeight instead of the actual window size, because at this time, the dock's window may not have its definite size.
-							cd_debug ("rect %d; %d", (int)rect.x, (int)rect.width);
-						}
-						else
-						{
-							rect.x = 0;
-							rect.y = pIcon->fXAtRest + 2 * my_fPanelRadius;  // we let a few pixels to be able to grab the separtator, and to avoid leaving the dock too easily.
-							rect.width = pDock->iMaxDockHeight;
-							rect.height = pData->fGroupGap - 4 * my_fPanelRadius;
-						}
-						cairo_region_subtract_rectangle (pDock->pShapeBitmap, &rect);
-						bValidGroup = FALSE;
+						rect.x = xi;
+						rect.y = 0;
+						rect.width = w;
+						rect.height = h;
+						cd_debug ("rect %d; %d", (int)rect.x, (int)rect.width);
 					}
+					else
+					{
+						rect.x = 0;
+						rect.y = xi;
+						rect.width = h;
+						rect.height = w;
+					}
+					cairo_region_subtract_rectangle (pDock->pShapeBitmap, &rect);
+					bValidGroup = FALSE;
+					bHasGroups = TRUE;
+				}
+			}
+			else
+			{
+				bValidGroup = TRUE;
+			}
+		}
+		
+		// if there is only a single group, make the outside transparent
+		if (! bHasGroups)
+		{
+			// left screen edge -> first icon
+			if (pDock->fAlign > 0)
+			{
+				xi = pDock->fAlign * pData->fGroupGap - my_fPanelRadius;
+				if (pDock->container.bIsHorizontal)
+				{
+					rect.x = 0.;  // left screen edge
+					rect.y = 0;
+					rect.width = xi;  // to first icon
+					rect.height = h;
+					cd_debug ("rect %d; %d (%s)", (int)rect.x, (int)rect.width, pIcon->cName);
 				}
 				else
 				{
-					bValidGroup = TRUE;
+					rect.x = 0;
+					rect.y = 0.;
+					rect.width = h;
+					rect.height = xi;
 				}
+				cairo_region_subtract_rectangle (pDock->pShapeBitmap, &rect);
 			}
-		#endif
+			
+			// last icon -> right screen edge
+			if (pDock->fAlign < 1)
+			{
+				xi = pDock->iMaxDockWidth - (1 - pDock->fAlign) * pData->fGroupGap + my_fPanelRadius;
+				if (pDock->container.bIsHorizontal)
+				{
+					rect.x = xi;  // last icon
+					rect.y = 0;
+					rect.width = pDock->iMaxDockWidth - xi;  // to right screen edge
+					rect.height = h;
+					cd_debug ("rect %d; %d", (int)rect.x, (int)rect.width);
+				}
+				else
+				{
+					rect.x = 0;
+					rect.y = xi;
+					rect.width = h;
+					rect.height = pDock->iMaxDockWidth - xi;
+				}
+				cairo_region_subtract_rectangle (pDock->pShapeBitmap, &rect);
+			}
+		}
 	}
 }
 
