@@ -126,84 +126,6 @@ static gchar *_cd_get_icon_path (GIcon *pIcon, const gchar *cTargetURI)  // cTar
 	return cIconPath;
 }
 
-
-static void _cd_find_mount_from_volume_name (const gchar *cVolumeName, GMount **pFoundMount, gchar **cURI, gchar **cIconName)
-{
-	g_return_if_fail (cVolumeName != NULL);
-	cd_message ("%s (%s)", __func__, cVolumeName);
-	GFile *pFile = g_file_new_for_uri ("computer://");
-	GError *erreur = NULL;
-	const gchar *cAttributes = G_FILE_ATTRIBUTE_STANDARD_TYPE","
-		G_FILE_ATTRIBUTE_STANDARD_NAME","
-		G_FILE_ATTRIBUTE_STANDARD_ICON","
-		G_FILE_ATTRIBUTE_STANDARD_TARGET_URI","
-		G_FILE_ATTRIBUTE_MOUNTABLE_UNIX_DEVICE;
-	GFileEnumerator *pFileEnum = g_file_enumerate_children (pFile,
-		cAttributes,
-		G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS,
-		NULL,
-		&erreur);
-	if (erreur != NULL)
-	{
-		cd_warning ("gvfs-integration : %s", erreur->message);
-		g_error_free (erreur);
-		g_object_unref (pFile);
-		return ;
-	}
-	
-	GFileInfo *pFileInfo;
-	do
-	{
-		pFileInfo = g_file_enumerator_next_file (pFileEnum, NULL, &erreur);
-		if (erreur != NULL)
-		{
-			cd_warning ("gvfs-integration : %s", erreur->message);
-			g_error_free (erreur);
-			erreur = NULL;
-		}
-		else
-		{
-			if (pFileInfo == NULL)
-				break ;
-			GFileType iFileType = g_file_info_get_file_type (pFileInfo);
-			if (iFileType == G_FILE_TYPE_MOUNTABLE)
-			{
-				const gchar *cFileName = g_file_info_get_name (pFileInfo);
-				cd_debug ("  test of  %s...", cFileName);
-				const gchar *cTargetURI = g_file_info_get_attribute_string (pFileInfo, G_FILE_ATTRIBUTE_STANDARD_TARGET_URI);
-				
-				GMount *pMount = NULL;
-				if (cTargetURI != NULL)
-				{
-					GFile *file = g_file_new_for_uri (cTargetURI);
-					pMount = g_file_find_enclosing_mount (file, NULL, NULL);
-					//g_object_unref (file);
-				}
-				if (pMount != NULL)
-				{
-					gchar *cName = g_mount_get_name (pMount);
-					cd_message ("    mount : %s", cName);
-					if (cName != NULL && strcmp (cName, cVolumeName) == 0)
-					{
-						cd_debug ("Found");
-						*pFoundMount = pMount;
-						*cURI = g_strconcat ("computer:///", cFileName, NULL);
-						GIcon *pSystemIcon = g_mount_get_icon (pMount);
-						*cIconName = _cd_get_icon_path (pSystemIcon, NULL);
-						g_object_unref (pSystemIcon);
-						g_free (cName);
-						break ;
-					}
-					g_free (cName);
-				}
-			}
-			g_object_unref (pFileInfo);
-		}
-	} while (TRUE);
-	g_object_unref (pFileEnum);
-	g_object_unref (pFile);
-}
-
 static GDrive *_cd_find_drive_from_name (const gchar *cName)
 {
 	g_return_val_if_fail (cName != NULL, NULL);
@@ -308,54 +230,10 @@ static void cairo_dock_gio_vfs_get_file_info (const gchar *cBaseURI, gchar **cNa
 	
 	// make it a valid URI.
 	gchar *cValidUri;
-	if (strncmp (cBaseURI, "x-nautilus-desktop://", 21) == 0)  // shortcut on the desktop (nautilus)
+	if (g_str_has_prefix (cBaseURI, "x-nautilus-desktop://"))  // shortcut on the desktop (nautilus)
 	{
-		gchar *cNautilusFile = g_strdup (cBaseURI+14);
-		memcpy (cNautilusFile, "file", 4);
-		if (g_str_has_suffix (cBaseURI, ".volume"))
-		{
-			cNautilusFile[strlen(cNautilusFile)-7] = '\0';
-		}
-		else if (g_str_has_suffix (cBaseURI, ".drive"))
-		{
-			cNautilusFile[strlen(cNautilusFile)-6] = '\0';
-		}
-		cValidUri = g_filename_from_uri (cNautilusFile, NULL, &erreur);
-		if (erreur != NULL)
-		{
-			cd_warning ("gvfs-integration : %s", erreur->message);
-			g_error_free (erreur);
-			return ;
-		}
-		gchar *cVolumeName = cValidUri + 1;  // on saute le '/'.
-		cd_message ("cVolumeName : %s", cVolumeName);
-		
-		GMount *pMount = NULL;
-		gchar *uri=NULL, *iconname=NULL;
-		_cd_find_mount_from_volume_name (cVolumeName, &pMount, &uri, &iconname);
-		g_return_if_fail (pMount != NULL);
-		
-		if (cURI)
-			*cURI = uri;
-		else
-			g_free (uri);
-		if (cIconName)
-			*cIconName = iconname;
-		else
-			g_free (iconname);
-		if (cName)
-			*cName = g_strdup (cVolumeName);
-		if (bIsDirectory)
-			*bIsDirectory = TRUE;
-		if (iVolumeID)
-			*iVolumeID = 1;
-		if (fOrder)
-			*fOrder = 0;
-		//g_object_unref (pMount);
-		
-		g_free (cValidUri);
-		//g_free (cNautilusFile);
-		return;
+		const gchar *cDesktopPath = g_get_user_special_dir (G_USER_DIRECTORY_DESKTOP);
+		cValidUri = g_strdup_printf ("file://%s%s", cDesktopPath, cBaseURI+21);
 	}
 	else  // normal file
 	{
@@ -363,7 +241,8 @@ static void cairo_dock_gio_vfs_get_file_info (const gchar *cBaseURI, gchar **cNa
 			cValidUri = g_filename_to_uri (cBaseURI, NULL, NULL);
 		else
 			cValidUri = g_strdup (cBaseURI);
-		if (*cBaseURI == ':' || *cValidUri == ':')  // cas bizarre au demontage d'un signet ftp quand celui-ci n'est pas accessible plantage dans dbus).
+		// strange case when unmounting a FTP bookmark when it's not available: crash with DBus
+		if (*cBaseURI == ':' || *cValidUri == ':')
 		{
 			cd_warning ("invalid URI (%s ; %s), skip it", cBaseURI, cValidUri);
 			g_free (cValidUri);
@@ -385,8 +264,7 @@ static void cairo_dock_gio_vfs_get_file_info (const gchar *cBaseURI, gchar **cNa
 		#if (GLIB_MAJOR_VERSION > 2) || (GLIB_MAJOR_VERSION == 2 && GLIB_MINOR_VERSION >= 20)
 		///G_FILE_ATTRIBUTE_PREVIEW_ICON","
 		#endif
-		G_FILE_ATTRIBUTE_STANDARD_TARGET_URI","
-		G_FILE_ATTRIBUTE_MOUNTABLE_UNIX_DEVICE;
+		G_FILE_ATTRIBUTE_STANDARD_TARGET_URI;
 	GFileInfo *pFileInfo = g_file_query_info (pFile,
 		cQuery,
 		G_FILE_QUERY_INFO_NONE,  /// G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS
@@ -445,12 +323,13 @@ static void cairo_dock_gio_vfs_get_file_info (const gchar *cBaseURI, gchar **cNa
 			{
 				GFile *file = g_file_new_for_uri (cTargetURI);
 				pMount = g_file_find_enclosing_mount (file, NULL, NULL);
-				//g_object_unref (file);
+				g_object_unref (file);
 			}
 			if (pMount != NULL)
 			{
 				*cName = g_mount_get_name (pMount);
 				cd_message ("un GMount existe (%s)",* cName);
+				g_object_unref (pMount);
 			}
 			else
 			{
@@ -477,8 +356,8 @@ static void cairo_dock_gio_vfs_get_file_info (const gchar *cBaseURI, gchar **cNa
 				}
 				if (*cName == NULL)
 					*cName = cMountName;
-				//else
-					//g_free (cMountName);
+				else
+					g_free (cMountName);
 			}
 			if (*cName ==  NULL)
 				*cName = g_strdup (cFileName);
@@ -527,14 +406,14 @@ static void cairo_dock_gio_vfs_get_file_info (const gchar *cBaseURI, gchar **cNa
 		{
 			gchar *cHostname = NULL;
 			GError *erreur = NULL;
-			gchar *cFilePath = g_filename_from_uri (cBaseURI, &cHostname, &erreur);
+			gchar *cFilePath = g_filename_from_uri (*cURI, &cHostname, &erreur);
 			if (erreur != NULL)
 			{
 				g_error_free (erreur);
 			}
 			else if (cHostname == NULL || strcmp (cHostname, "localhost") == 0)  // on ne recupere la vignette que sur les fichiers locaux.
 			{
-				*cIconName = g_strdup (cFilePath);
+				*cIconName = cFilePath;
 				cairo_dock_remove_html_spaces (*cIconName);
 			}
 			g_free (cHostname);
@@ -597,7 +476,6 @@ static Icon *_cd_get_icon_for_volume (GVolume *pVolume, GMount *pMount)
 		cCommand,
 		NULL,
 		0);
-	pNewIcon->iTrueType = CAIRO_DOCK_ICON_TYPE_FILE;
 	pNewIcon->iVolumeID = 1;
 	pNewIcon->cBaseURI = g_strdup (pNewIcon->cCommand);
 	cd_message (" => %s", pNewIcon->cCommand);
@@ -727,18 +605,15 @@ static GList *cairo_dock_gio_vfs_list_directory (const gchar *cBaseURI, CairoDoc
 	GFile *pFile = g_file_new_for_uri (cURI);
 	GError *erreur = NULL;
 	const gchar *cAttributes = G_FILE_ATTRIBUTE_STANDARD_TYPE","
-		G_FILE_ATTRIBUTE_STANDARD_SIZE","
-		G_FILE_ATTRIBUTE_TIME_MODIFIED","
 		G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE","
 		G_FILE_ATTRIBUTE_STANDARD_NAME","
-		G_FILE_ATTRIBUTE_STANDARD_IS_HIDDEN","
 		G_FILE_ATTRIBUTE_STANDARD_ICON","
 		G_FILE_ATTRIBUTE_THUMBNAIL_PATH","
+		G_FILE_ATTRIBUTE_STANDARD_IS_HIDDEN","
 		#if (GLIB_MAJOR_VERSION > 2) || (GLIB_MAJOR_VERSION == 2 && GLIB_MINOR_VERSION >= 20)
 		///G_FILE_ATTRIBUTE_PREVIEW_ICON","
 		#endif
-		G_FILE_ATTRIBUTE_STANDARD_TARGET_URI","
-		G_FILE_ATTRIBUTE_MOUNTABLE_UNIX_DEVICE;
+		G_FILE_ATTRIBUTE_STANDARD_TARGET_URI;
 	GFileEnumerator *pFileEnum = g_file_enumerate_children (pFile,
 		cAttributes,
 		G_FILE_QUERY_INFO_NONE,  /// G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS
@@ -785,7 +660,6 @@ static GList *cairo_dock_gio_vfs_list_directory (const gchar *cBaseURI, CairoDoc
 			gchar *cName = NULL;
 			
 			icon = cairo_dock_create_dummy_launcher (NULL, NULL, NULL, NULL, 0);
-			icon->iTrueType = CAIRO_DOCK_ICON_TYPE_FILE;
 			icon->iGroup = iNewIconsGroup;
 			icon->cBaseURI = g_strconcat (*cValidUri, "/", cFileName, NULL);
 			//g_print	 ("+ %s (mime:%s)n", icon->cBaseURI, cMimeType);
@@ -953,9 +827,12 @@ static gsize cairo_dock_gio_vfs_measure_directory (const gchar *cBaseURI, gint i
 		&erreur);
 	if (erreur != NULL)
 	{
-		cd_warning ("gvfs-integration : %s", erreur->message);
+		cd_warning ("gvfs-integration: %s (%s)", erreur->message, cURI);
 		g_error_free (erreur);
 		g_object_unref (pFile);
+		if (cURI != cBaseURI)
+			g_free (cURI);
+		g_atomic_int_set (pCancel, TRUE);
 		return 0;
 	}
 	
@@ -967,7 +844,10 @@ static gsize cairo_dock_gio_vfs_measure_directory (const gchar *cBaseURI, gint i
 		pFileInfo = g_file_enumerator_next_file (pFileEnum, NULL, &erreur);
 		if (erreur != NULL)
 		{
-			cd_warning ("gvfs-integration : %s", erreur->message);
+			cd_warning ("gvfs-integration : %s (%s [%s]: %s)", erreur->message,
+				g_file_info_get_name (pFileInfo),
+				g_file_info_get_display_name (pFileInfo),
+				g_file_info_get_content_type (pFileInfo));
 			g_error_free (erreur);
 			erreur = NULL;
 			continue;
@@ -1002,7 +882,7 @@ static gsize cairo_dock_gio_vfs_measure_directory (const gchar *cBaseURI, gint i
 		g_object_unref (pFileInfo);
 	} while (! g_atomic_int_get (pCancel));
 	if (*pCancel)
-		cd_debug ("mesure annulee");
+		cd_debug ("measure cancelled");
 	
 	g_object_unref (pFileEnum);
 	g_object_unref (pFile);
@@ -1106,7 +986,7 @@ static GMount *_cd_find_mount_from_uri (const gchar *cURI, gchar **cTargetURI)
 	GMount *pMount = NULL;
 	if (_cTargetURI != NULL)
 	{
-		cd_message ("  pointe sur %s", _cTargetURI);
+		cd_debug ("  pointe sur %s", _cTargetURI);
 		GFile *file = g_file_new_for_uri (_cTargetURI);
 		pMount = g_file_find_enclosing_mount (file, NULL, NULL);
 		g_object_unref (file);
@@ -1122,16 +1002,36 @@ static gchar *cairo_dock_gio_vfs_is_mounted (const gchar *cURI, gboolean *bIsMou
 {
 	cd_message ("%s (%s)", __func__, cURI);
 	gchar *cTargetURI = NULL;
-	GMount *pMount = _cd_find_mount_from_uri (cURI, &cTargetURI);
-	cd_message (" cTargetURI : %s", cTargetURI);
-	if (pMount != NULL)
-		*bIsMounted = TRUE;
-	else
+	
+	GFile *pFile = g_file_new_for_uri (cURI);
+	GFileType iType = g_file_query_file_type (pFile, G_FILE_QUERY_INFO_NONE, NULL);
+	g_object_unref (pFile);
+	cd_debug ("iType: %d\n", iType);
+	
+	if (iType == G_FILE_TYPE_MOUNTABLE)  // look for the mount point it targets
 	{
-		if (cTargetURI != NULL && strcmp (cTargetURI, "file:///") == 0)  // cas particulier ?
+		GMount *pMount = _cd_find_mount_from_uri (cURI, &cTargetURI);
+		cd_debug (" cTargetURI : %s", cTargetURI);
+		if (pMount != NULL)
+		{
 			*bIsMounted = TRUE;
+			g_object_unref (pMount);
+		}
 		else
-			*bIsMounted = FALSE;
+		{
+			if (cTargetURI != NULL && strcmp (cTargetURI, "file:///") == 0)  // cas particulier ?
+				*bIsMounted = TRUE;
+			else
+				*bIsMounted = FALSE;
+		}
+	}
+	else if (iType == G_FILE_TYPE_UNKNOWN)  // probably a remote share folder or whatever that is not yet mounted
+	{
+		*bIsMounted = FALSE;
+	}
+	else  // any other types (directory, regular file, etc) that is on (or point to) a monted volume.
+	{
+		*bIsMounted = TRUE;
 	}
 	return cTargetURI;
 }
@@ -1211,8 +1111,12 @@ static void _gio_vfs_mount_callback (gpointer pObject, GAsyncResult *res, gpoint
 	GError *erreur = NULL;
 	gboolean bSuccess;
 	if (GPOINTER_TO_INT (data[1]) == 1)
-		bSuccess = (g_file_mount_mountable_finish (G_FILE (pObject), res, &erreur) != NULL);
-		//bSuccess = (g_volume_mount_finish (G_VOLUME (pObject), res, &erreur));
+	{
+		if (data[5])
+			bSuccess = (g_file_mount_mountable_finish (G_FILE (pObject), res, &erreur) != NULL);
+		else
+			bSuccess = g_file_mount_enclosing_volume_finish (G_FILE (pObject), res, &erreur);
+	}
 	else if (GPOINTER_TO_INT (data[1]) == 0)
 		#if GLIB_CHECK_VERSION (2, 22, 0)
 		bSuccess = g_mount_unmount_with_operation_finish (G_MOUNT (pObject), res, &erreur);
@@ -1247,18 +1151,41 @@ static void cairo_dock_gio_vfs_mount (const gchar *cURI, int iVolumeID, CairoDoc
 	gchar *cTargetURI = _cd_find_target_uri (cURI);
 	GFile *pFile = g_file_new_for_uri (cURI);
 	
-	gpointer *data = g_new (gpointer, 5);  // libere dans la callback.
+	gpointer *data = g_new (gpointer, 6);  // libere dans la callback.
 	data[0] = pCallback;
 	data[1] = GINT_TO_POINTER (1);  // mount
 	data[2] = (cTargetURI ? g_path_get_basename (cTargetURI) : g_strdup (cURI));
 	data[3] = g_strdup (cURI);
 	data[4] = user_data;
-	g_file_mount_mountable  (pFile,
-		G_MOUNT_MOUNT_NONE,
-		NULL,
-		NULL,
-		(GAsyncReadyCallback) _gio_vfs_mount_callback,
-		data);
+	
+	GMountOperation *mount_op = gtk_mount_operation_new (GTK_WINDOW (g_pPrimaryContainer->pWidget));
+	g_mount_operation_set_password_save (mount_op, G_PASSWORD_SAVE_FOR_SESSION);
+	
+	GFileType iType = g_file_query_file_type (pFile, G_FILE_QUERY_INFO_NONE, NULL);
+	cd_debug ("iType: %d\n", iType);
+	if (iType == G_FILE_TYPE_MOUNTABLE)
+	{
+		data[5] = GINT_TO_POINTER (1);
+		g_file_mount_mountable  (pFile,
+			G_MOUNT_MOUNT_NONE,
+			mount_op,
+			NULL,
+			(GAsyncReadyCallback) _gio_vfs_mount_callback,
+			data);
+	}
+	else  // smb share folders typically have an unknown type; we have to use the other mount function for these types of mount points.
+	{
+		data[5] = GINT_TO_POINTER (0);
+		g_file_mount_enclosing_volume (pFile,
+			G_MOUNT_MOUNT_NONE,
+			mount_op,
+			NULL,
+			(GAsyncReadyCallback) _gio_vfs_mount_callback,
+			data);
+	}
+	// unref mount_op here - g_file_mount_enclosing_volume() does ref for itself
+	g_object_unref (mount_op);
+	g_object_unref (pFile);
 	g_free (cTargetURI);
 }
 
