@@ -46,11 +46,9 @@ struct _AppletConfig {
 	gchar *cThemePath;
 	gchar *cRenderer;
 	gchar *cMailApplication;
-	gchar *cMailClass;
 	gchar *cAnimation;
 	gint iAnimationDuration;
 	gboolean bPlaySound;
-	gboolean bStealTaskBarIcon;
 	gboolean bShowMessageContent;
 	gboolean bCheckOnStartup;
 	guint iNbMaxShown;
@@ -80,7 +78,7 @@ struct _AppletData {
 
 
 typedef struct {
-    CairoDockModuleInstance *pAppletInstance;
+    GldiModuleInstance *pAppletInstance;
     gchar *name;
     struct mailstorage *storage;
     struct mailfolder *folder;
@@ -94,11 +92,12 @@ typedef struct {
     int auth_type;
     gchar *path;
     guint timeout;
-    CairoDockTask *pAccountMailTimer;
+    GldiTask *pAccountMailTimer;
     Icon *icon;
+    gchar *cIconName;
     gboolean bInitialized;
-    GList *pUnseenMessageList;  // liste de gchar*
-    GList *pUnseenMessageUid;  // liste de gchar*
+    GList *pUnseenMessageList;  // list of gchar*
+    GList *pUnseenMessageUid;  // list of gchar*
 
     gchar *cMailApp;
 
