@@ -28,332 +28,56 @@
 
 #define CD_SHORTCUT_DEFAULT_DIRECTORY_ICON_FILENAME "inode-directory"
 
-void cd_shortcuts_on_bookmarks_event (CairoDockFMEventType iEventType, const gchar *cURI, GldiModuleInstance *myApplet)
+static const gchar * _get_custom_name_and_uri (gchar *cOneBookmark, gchar **cURI)
 {
-	static int iTime = 0;
-	iTime ++;
-	CD_APPLET_ENTER;
-	//g_print ("%s (%d)\n", __func__, iEventType);
-	GList *pIconsList = CD_APPLET_MY_ICONS_LIST;
-	Icon *icon;
-	GList *ic;
-	for (ic = pIconsList; ic != NULL; ic = ic->next)  // optimization: skip the disks and networks, and point on the first bookmark.
+	const gchar *cUserName = NULL;
+	// should not happen if we add bookmarks via the dock or Nautilus
+	if (*cOneBookmark == '/')
 	{
-		icon = ic->data;
-		if (icon->iGroup == (CairoDockIconGroup) CD_BOOKMARK_GROUP)
-			break;
+		// for 'gvfs_launch_uri':
+		*cURI = g_strconcat ("file://", cOneBookmark, NULL);
+		g_free (cOneBookmark);
 	}
-	pIconsList = ic;  // Note that since the first bookmark is always the Home Folder, 'pIconsList' will never change when inserting/removing a bookmark.
-	GldiContainer *pContainer = CD_APPLET_MY_ICONS_LIST_CONTAINER;
-	CD_APPLET_LEAVE_IF_FAIL (pContainer != NULL);
-	
-	if (iEventType == CAIRO_DOCK_FILE_CREATED || iEventType == CAIRO_DOCK_FILE_MODIFIED)  // le fichier des bookmarks a ete modifie.
+	else  // it's a valid URI but does it have a custom name?
 	{
-		cd_message ("The bookmarks list has changed");
-		
-		//\____________________ On lit le fichier des signets.
-		gchar *cBookmarkFilePath = g_strdup_printf ("%s/"GTK_BOOKMARKS_PATH, g_getenv ("HOME"));
-		gchar *cContent = NULL;
-		gsize length=0;
-		GError *erreur = NULL;
-		g_file_get_contents  (cBookmarkFilePath, &cContent, &length, &erreur);
-		if (erreur != NULL)
+		*cURI = cOneBookmark;
+		// a custom name is separated with a whitespace (no whitespace in the URI)
+		gchar *str = strchr (cOneBookmark, ' ');
+		if (str != NULL)
 		{
-			cd_warning ("when trying to get the bookmarks : %s", erreur->message);
-			g_error_free (erreur);
+			cUserName = str + 1;
+			*str = '\0';
 		}
-		else
-		{
-			gchar **cBookmarksList = g_strsplit (cContent, "\n", -1);
-			g_free (cContent);
-			
-			//\____________________ On parcourt le contenu.
-			double fCurrentOrder = 1.;  // bookmarks are listed in the order of the file; we need to reorder each icon in case a bookmark has changed its place, or if a new one appeared (the first one is always the Home Folder).
-			gchar *cOneBookmark;
-			Icon *pNewIcon;
-			gchar *cName, *cRealURI, *cIconName, *cUserName;
-			gboolean bIsDirectory;
-			int iVolumeID;
-			double fOrder;
-			int i;
-			for (i = 0; cBookmarksList[i] != NULL; i ++)
-			{
-				cOneBookmark = cBookmarksList[i];
-				if (*cOneBookmark == '\0' || *cOneBookmark == '#')
-				{
-					g_free (cOneBookmark);
-					continue;
-				}
-				
-				// on recupere le nom a afficher.
-				cUserName = NULL;
-				if (cOneBookmark != NULL && *cOneBookmark == '/')  // ne devrait pas arriver si on ajoute les signets via le dock ou Nautilus.
-				{
-					gchar *tmp = cOneBookmark;
-					cOneBookmark = g_strconcat ("file://", cOneBookmark, NULL);  // sinon launch_uri() ne marche pas sous Gnome.
-					g_free (tmp);
-				}
-				else  // c'est une URI valide, on regarde si il y'a un nom utilisateur.
-				{
-					gchar *str = strchr (cOneBookmark, ' ');  // pas d'espace dans une URI, donc le 1er espace signifie la separation entre URI et nom utilisateur.
-					if (str != NULL)
-					{
-						cUserName = str + 1;
-						*str = '\0';
-					}
-				}
-				
-				// on cree une icone pour le signet si aucune n'existe ou qu'il a change.
-				Icon *pExistingIcon = cairo_dock_get_icon_with_base_uri (pIconsList, cOneBookmark);
-				if (pExistingIcon != NULL)
-				{
-					if ((cUserName && cairo_dock_strings_differ (pExistingIcon->cName, cUserName))
-					|| cURI == NULL)  // signet inexistant ou qui a change => on le cree. 'cUserName' may be NULL if the user has never set a user-name yet, but once he does, 'cUserName' is not NULL. so if 'cUserName' is NULL, it has not changed.
-					{
-						//g_print ("le signet '%s' a change, on le recree\n", pExistingIcon->cName);
-						CD_APPLET_REMOVE_ICON_FROM_MY_ICONS_LIST (pExistingIcon);
-						pExistingIcon = NULL;
-					}
-					else
-					{
-						CDDiskUsage *pDiskUsage = CD_APPLET_GET_MY_ICON_DATA (pExistingIcon);
-						if (! pDiskUsage)
-						{
-							pDiskUsage = g_new0 (CDDiskUsage, 1);
-							CD_APPLET_SET_MY_ICON_DATA (pExistingIcon, pDiskUsage);
-						}
-						pDiskUsage->iLastCheckTime = iTime;
-						pExistingIcon->fOrder = fCurrentOrder ++;
-					}
-				}
-				if (pExistingIcon == NULL)
-				{
-					//g_print ("new bookmark : '%s'\n", cOneBookmark);
-					
-					cName = NULL;
-					cRealURI = NULL;
-					cIconName = NULL;
-					if (cairo_dock_fm_get_file_info (cOneBookmark, &cName, &cRealURI, &cIconName, &bIsDirectory, &iVolumeID, &fOrder, CAIRO_DOCK_FM_SORT_BY_NAME))
-					{
-						cd_message (" + 1 bookmark : %s", cOneBookmark);
-						if (cUserName != NULL)
-						{
-							g_free (cName);
-							cName = g_strdup (cUserName);
-						}
-						else if (cName == NULL)  // cas d'un bookmark situe sur un volume non monte.
-						{
-							gchar *cGuessedName = g_path_get_basename (cOneBookmark);
-							cairo_dock_remove_html_spaces (cGuessedName);
-							cName = g_strdup_printf ("%s\n[%s]", cGuessedName, D_("Unmounted"));
-							g_free (cGuessedName);
-						}
-						if (cRealURI == NULL)
-							cRealURI = g_strdup (cOneBookmark);
-						if (cIconName == NULL)
-							cIconName = cairo_dock_search_icon_s_path (CD_SHORTCUT_DEFAULT_DIRECTORY_ICON_FILENAME, CAIRO_DOCK_DEFAULT_ICON_SIZE);
-						
-						pNewIcon = cairo_dock_create_dummy_launcher (cName,
-							cIconName,
-							cRealURI,
-							NULL,
-							fCurrentOrder++);
-						pNewIcon->iGroup = CD_BOOKMARK_GROUP;
-						pNewIcon->cBaseURI = cOneBookmark;
-						pNewIcon->iVolumeID = iVolumeID;
-						CDDiskUsage *pDiskUsage = g_new0 (CDDiskUsage, 1);
-						pDiskUsage->iLastCheckTime = iTime;
-						CD_APPLET_SET_MY_ICON_DATA (pNewIcon, pDiskUsage);
-						
-						CD_APPLET_ADD_ICON_IN_MY_ICONS_LIST (pNewIcon);
-					}
-					else
-					{
-						cd_warning ("couldn't get info on bookmark '%s'", cOneBookmark);
-						g_free (cOneBookmark);
-					}
-				}
-			}
-			g_free (cBookmarksList);
-			
-			//\____________________ remove the old bookmarks.
-			///pIconsList = CD_APPLET_MY_ICONS_LIST;
-			GList *next_ic;
-			for (ic = pIconsList; ic != NULL; ic = next_ic)
-			{
-				next_ic = ic->next;
-				icon = ic->data;
-				if (icon->iGroup == (CairoDockIconGroup) CD_BOOKMARK_GROUP)
-				{
-					CDDiskUsage *pDiskUsage = CD_APPLET_GET_MY_ICON_DATA (icon);
-					if (! pDiskUsage || pDiskUsage->iLastCheckTime < iTime)
-					{
-						cd_debug ("this bookmark is too old (%s)", icon->cName);
-						CD_APPLET_REMOVE_ICON_FROM_MY_ICONS_LIST (icon);
-					}
-				}
-			}
-			pIconsList = CD_APPLET_MY_ICONS_LIST;
-			cairo_dock_sort_icons_by_order (pIconsList);  // again, since 'Home Folder' is always the first bookmark, the head of the list won't change even if there are only bookmarks (so we don't need to re-assigne it to the container).
-		}
-		g_free (cBookmarkFilePath);
 	}
-	CD_APPLET_LEAVE();
-}
-
-void cd_shortcuts_remove_one_bookmark (const gchar *cURI)
-{
-	g_return_if_fail (cURI != NULL);
-	cd_message ("%s (%s)", __func__, cURI);
-	
-	gchar *cBookmarkFilePath = g_strdup_printf ("%s/"GTK_BOOKMARKS_PATH, g_getenv ("HOME"));
-	gchar *cContent = NULL;
-	gsize length=0;
-	GError *erreur = NULL;
-	g_file_get_contents  (cBookmarkFilePath, &cContent, &length, &erreur);
-	if (erreur != NULL)
-	{
-		cd_warning ("while trying to read bookmarks file : %s", erreur->message);
-		g_error_free (erreur);
-	}
-	else
-	{
-		gchar **cBookmarksList = g_strsplit (cContent, "\n", -1);
-		g_free (cContent);
-		gchar *cOneBookmark, *str;
-		gboolean bFound = FALSE;
-		int i = 0;
-		for (i = 0; cBookmarksList[i] != NULL; i ++)
-		{
-			cOneBookmark = cBookmarksList[i];
-			if (*cOneBookmark == '\0' || *cOneBookmark == '#')
-				continue;
-			
-			str = strchr (cOneBookmark, ' ');
-			if ((str && strncmp (cOneBookmark, cURI, str - cOneBookmark) == 0) || (!str && strcmp (cOneBookmark, cURI) == 0))
-			{
-				// remove this element from the array
-				int j;
-				for (j = i; cBookmarksList[j] != NULL; j ++)
-				{
-					cBookmarksList[j] = cBookmarksList[j+1];
-				}
-				// free the removed element.
-				g_free (cOneBookmark);
-				// quit the loop
-				bFound = TRUE;
-				break;
-			}
-		}
-		
-		if (! bFound)
-		{
-			cd_warning ("bookmark '%s' not found", cURI);
-		}
-		else
-		{
-			cContent = g_strjoinv ("\n", cBookmarksList);
-			g_file_set_contents (cBookmarkFilePath, cContent, -1, &erreur);
-			if (erreur != NULL)
-			{
-				cd_warning ("while trying to write bookmarks file : %s", erreur->message);
-				g_error_free (erreur);
-			}
-			g_free (cContent);
-		}
-		g_strfreev (cBookmarksList);
-	}
-	g_free (cBookmarkFilePath);
-}
-
-void cd_shortcuts_rename_one_bookmark (const gchar *cURI, const gchar *cName)
-{
-	g_return_if_fail (cURI != NULL);
-	cd_message ("%s (%s, %s)", __func__, cURI, cName);
-	
-	gchar *cBookmarkFilePath = g_strdup_printf ("%s/"GTK_BOOKMARKS_PATH, g_getenv ("HOME"));
-	gchar *cContent = NULL;
-	gsize length=0;
-	GError *erreur = NULL;
-	g_file_get_contents  (cBookmarkFilePath, &cContent, &length, &erreur);
-	if (erreur != NULL)
-	{
-		cd_warning ("while trying to read bookmarks file : %s", erreur->message);
-		g_error_free (erreur);
-	}
-	else
-	{
-		gchar **cBookmarksList = g_strsplit (cContent, "\n", -1);
-		g_free (cContent);
-		gchar *cOneBookmark, *str;
-		int i = 0;
-		for (i = 0; cBookmarksList[i] != NULL; i ++)
-		{
-			cOneBookmark = cBookmarksList[i];
-			if (*cOneBookmark == '\0' || *cOneBookmark == '#')
-				continue;
-			
-			str = strchr (cOneBookmark, ' ');
-			if ((str && strncmp (cOneBookmark, cURI, str - cOneBookmark) == 0) || (!str && strcmp (cOneBookmark, cURI) == 0))
-			{
-				cBookmarksList[i] = g_strdup_printf ("%s %s", cURI, cName);
-				g_free (cOneBookmark);
-				break;
-			}
-		}
-		
-		if (cBookmarksList[i] == NULL)
-		{
-			cd_warning ("bookmark '%s' not found", cURI);
-		}
-		else
-		{
-			cContent = g_strjoinv ("\n", cBookmarksList);
-			g_file_set_contents (cBookmarkFilePath, cContent, -1, &erreur);
-			if (erreur != NULL)
-			{
-				cd_warning ("while trying to write bookmarks file : %s", erreur->message);
-				g_error_free (erreur);
-			}
-			g_free (cContent);
-		}
-		g_strfreev (cBookmarksList);
-	}
-	g_free (cBookmarkFilePath);
-}
-
-void cd_shortcuts_add_one_bookmark (const gchar *cURI)
-{
-	g_return_if_fail (cURI != NULL);
-	cd_message ("%s (%s)", __func__, cURI);
-	
-	gchar *cBookmarkFilePath = g_strdup_printf ("%s/"GTK_BOOKMARKS_PATH, g_getenv ("HOME"));
-	
-	// see if we need to add a new line before the new URI.
-	gchar *cContent = NULL;
-	gsize length = 0;
-	g_file_get_contents (cBookmarkFilePath,
-		&cContent,
-		&length,
-		NULL);
-	gboolean bAddNewLine = (cContent && length > 0 && cContent[length-1] != '\n');
-	g_free (cContent);
-	
-	// append the new URI to the file.
-	FILE *f = fopen (cBookmarkFilePath, "a");
-	if (f != NULL)
-	{
-		gchar *cNewLine = g_strdup_printf ("%s%s\n", bAddNewLine ? "\n" : "", cURI);
-		fputs(cNewLine, f);
-		g_free (cNewLine);
-		fclose (f);
-	}
-	g_free (cBookmarkFilePath);
+	return cUserName;
 }
 
 static Icon * _cd_shortcuts_get_icon (gchar *cFileName, const gchar *cUserName, double fCurrentOrder)
 {
 	cd_debug ("New icon: %s, %s, %f", cFileName, cUserName, fCurrentOrder);
+
+	/* Nautilus adds custom prefixes which are not supported by gvfs...
+	 * gvfs-integration plugin can read x-nautilus-desktop but not others, e.g.:
+	 * x-nautilus-search://0/ => specific to Nautilus: open these URI with it.
+	 * Note that all these URI have a user-name
+	 */
+	if (g_str_has_prefix (cFileName, "x-nautilus-")
+	    && ! g_str_has_prefix (cFileName, "x-nautilus-desktop://"))
+	{
+		Icon *pNewIcon = cairo_dock_create_dummy_launcher (
+			cUserName ? g_strdup (cUserName) : g_strdup (cFileName),
+			cairo_dock_search_icon_s_path (
+				CD_SHORTCUT_DEFAULT_DIRECTORY_ICON_FILENAME,
+				CAIRO_DOCK_DEFAULT_ICON_SIZE),
+			g_strdup_printf ("nautilus %s", cFileName),
+			NULL,
+			fCurrentOrder);
+		pNewIcon->iGroup = CD_BOOKMARK_GROUP;
+		pNewIcon->cBaseURI = cFileName;
+		pNewIcon->iVolumeID = CD_VOLUME_ID_BOOKMARK_CMD;
+		return pNewIcon;
+	}
+
 	gchar *cName, *cRealURI, *cIconName;
 	gboolean bIsDirectory;
 	gint iVolumeID;
@@ -394,6 +118,299 @@ static Icon * _cd_shortcuts_get_icon (gchar *cFileName, const gchar *cUserName,
 	return pNewIcon;
 }
 
+static GList * _get_item_with_base_uri_icon (GList *pIconList, const gchar *cBaseURI)
+{
+	GList* ic;
+	Icon *pIcon;
+	for (ic = pIconList; ic != NULL; ic = ic->next)
+	{
+		pIcon = ic->data;
+		if (pIcon->cBaseURI != NULL && strcmp (pIcon->cBaseURI, cBaseURI) == 0)
+			return ic;
+	}
+	return NULL;
+}
+
+static void _remove_old_icons_and_free_list (GList *pOldBookmarkList)
+{
+	GList* ic;
+	Icon *pIcon;
+	for (ic = pOldBookmarkList; ic != NULL; ic = ic->next)
+	{
+		pIcon = ic->data;
+		CD_APPLET_REMOVE_ICON_FROM_MY_ICONS_LIST (pIcon);
+	}
+	g_list_free (pOldBookmarkList);
+}
+
+void cd_shortcuts_on_bookmarks_event (CairoDockFMEventType iEventType, const gchar *cURI, GldiModuleInstance *myApplet)
+{
+	static int iTime = 0;
+	iTime ++;
+	CD_APPLET_ENTER;
+	//g_print ("%s (%d)\n", __func__, iEventType);
+	GList *pIconsList = CD_APPLET_MY_ICONS_LIST;
+	GList *pOldBookmarkList;
+	Icon *icon;
+	GList *ic;
+	// optimization: skip the disks and networks, and point on the first bookmark.
+	for (ic = pIconsList; ic != NULL; ic = ic->next)
+	{
+		icon = ic->data;
+		if (icon->iGroup == (CairoDockIconGroup) CD_BOOKMARK_GROUP)
+			break;
+	}
+	/* Note that since the first bookmark is always the Home Folder,
+	 * 'pIconsList' will never change when inserting/removing a bookmark.
+	 */
+	pIconsList = ic;
+	GldiContainer *pContainer = CD_APPLET_MY_ICONS_LIST_CONTAINER;
+	CD_APPLET_LEAVE_IF_FAIL (pContainer != NULL);
+
+	// split the list: items can have been removed
+	pOldBookmarkList = pIconsList->next;
+	pIconsList->next = NULL;
+	pOldBookmarkList->prev = NULL;
+
+	// Bookmarks file has been modified
+	if (iEventType == CAIRO_DOCK_FILE_CREATED || iEventType == CAIRO_DOCK_FILE_MODIFIED)
+	{
+		cd_message ("The bookmarks list has changed");
+		
+		//\____________________ Read bookmarks file
+		gchar *cContent = NULL;
+		gsize length=0;
+		GError *erreur = NULL;
+		g_file_get_contents  (myData.cBookmarksURI, &cContent, &length, &erreur);
+		if (erreur != NULL)
+		{
+			cd_warning ("when trying to get the bookmarks : %s", erreur->message);
+			g_error_free (erreur);
+		}
+		else
+		{
+			gchar **cBookmarksList = g_strsplit (cContent, "\n", -1);
+			g_free (cContent);
+			
+			//\____________________ Read the content.
+			/* Bookmarks are listed in the order of the file; we need to
+			 * reorder each icon in case a bookmark has changed its place, or
+			 * if a new one appeared (the first one is always the Home Folder).
+			 */
+			double fCurrentOrder = 1.;
+			gchar *cOneBookmark;
+			Icon *pNewIcon, *pExistingIcon;
+			GList *pExistingIconNode;
+			const gchar *cUserName;
+			int i;
+			for (i = 0; cBookmarksList[i] != NULL; i ++)
+			{
+				cOneBookmark = cBookmarksList[i];
+				if (*cOneBookmark == '\0' || *cOneBookmark == '#')
+				{
+					g_free (cOneBookmark);
+					continue;
+				}
+				
+				// Grab the custom name if any
+				cUserName = _get_custom_name_and_uri (cBookmarksList[i], &cOneBookmark);
+				
+				// Check if the icon already exists and has changed
+				pExistingIconNode = _get_item_with_base_uri_icon (pOldBookmarkList, cOneBookmark);
+				if (pExistingIconNode != NULL)
+				{
+					pExistingIcon = pExistingIconNode->data;
+					// move this node to the subdock icons list
+					pOldBookmarkList = g_list_delete_link (pOldBookmarkList, pExistingIconNode);
+					pIconsList = g_list_insert (pIconsList, pExistingIcon, 1); // after the home, will be sorted later
+					if (cUserName && g_strcmp0 (pExistingIcon->cName, cUserName) != 0)
+					{
+						CD_APPLET_REMOVE_ICON_FROM_MY_ICONS_LIST (pExistingIcon); // will destroy it
+						pExistingIcon = NULL;
+					}
+					else
+					{
+						fCurrentOrder++;
+						g_free (cOneBookmark);
+					}
+				}
+				else
+					pExistingIcon = NULL;
+
+				if (pExistingIcon == NULL)
+				{
+					pNewIcon = _cd_shortcuts_get_icon (cOneBookmark,
+						cUserName, fCurrentOrder);
+					if (pNewIcon)
+					{
+						CD_APPLET_ADD_ICON_IN_MY_ICONS_LIST (pNewIcon);
+						fCurrentOrder++;
+					}
+					else
+					{
+						cd_warning ("couldn't get info on bookmark '%s'", cOneBookmark);
+						g_free (cOneBookmark);
+					}
+				}
+			}
+			g_free (cBookmarksList);
+
+			_remove_old_icons_and_free_list (pOldBookmarkList);
+
+			/* Again, since 'Home Folder' is always the first bookmark,
+			 * the head of the list won't change even if there are only bookmarks
+			 * (so we don't need to re-assigne it to the container).
+			 */
+			cairo_dock_sort_icons_by_order (pIconsList);
+		}
+	}
+	CD_APPLET_LEAVE();
+}
+
+void cd_shortcuts_remove_one_bookmark (const gchar *cURI, GldiModuleInstance *myApplet)
+{
+	g_return_if_fail (cURI != NULL);
+	cd_message ("%s (%s)", __func__, cURI);
+	
+	gchar *cContent = NULL;
+	gsize length=0;
+	GError *erreur = NULL;
+	g_file_get_contents  (myData.cBookmarksURI, &cContent, &length, &erreur);
+	if (erreur != NULL)
+	{
+		cd_warning ("while trying to read bookmarks file : %s", erreur->message);
+		g_error_free (erreur);
+	}
+	else
+	{
+		gchar **cBookmarksList = g_strsplit (cContent, "\n", -1);
+		g_free (cContent);
+		gchar *cOneBookmark, *str;
+		gboolean bFound = FALSE;
+		int i = 0;
+		for (i = 0; cBookmarksList[i] != NULL; i ++)
+		{
+			cOneBookmark = cBookmarksList[i];
+			if (*cOneBookmark == '\0' || *cOneBookmark == '#')
+				continue;
+			
+			str = strchr (cOneBookmark, ' ');
+			if ((str && strncmp (cOneBookmark, cURI, str - cOneBookmark) == 0)
+			    || (!str && strcmp (cOneBookmark, cURI) == 0))
+			{
+				// remove this element from the array
+				int j;
+				for (j = i; cBookmarksList[j] != NULL; j ++)
+				{
+					cBookmarksList[j] = cBookmarksList[j+1];
+				}
+				// free the removed element.
+				g_free (cOneBookmark);
+				// quit the loop
+				bFound = TRUE;
+				break;
+			}
+		}
+		
+		if (! bFound)
+		{
+			cd_warning ("bookmark '%s' not found", cURI);
+		}
+		else
+		{
+			cContent = g_strjoinv ("\n", cBookmarksList);
+			g_file_set_contents (myData.cBookmarksURI, cContent, -1, &erreur);
+			if (erreur != NULL)
+			{
+				cd_warning ("while trying to write bookmarks file : %s", erreur->message);
+				g_error_free (erreur);
+			}
+			g_free (cContent);
+		}
+		g_strfreev (cBookmarksList);
+	}
+}
+
+void cd_shortcuts_rename_one_bookmark (const gchar *cURI, const gchar *cName, GldiModuleInstance *myApplet)
+{
+	g_return_if_fail (cURI != NULL);
+	cd_message ("%s (%s, %s)", __func__, cURI, cName);
+	
+	gchar *cContent = NULL;
+	gsize length=0;
+	GError *erreur = NULL;
+	g_file_get_contents  (myData.cBookmarksURI, &cContent, &length, &erreur);
+	if (erreur != NULL)
+	{
+		cd_warning ("while trying to read bookmarks file : %s", erreur->message);
+		g_error_free (erreur);
+	}
+	else
+	{
+		gchar **cBookmarksList = g_strsplit (cContent, "\n", -1);
+		g_free (cContent);
+		gchar *cOneBookmark, *str;
+		int i = 0;
+		for (i = 0; cBookmarksList[i] != NULL; i ++)
+		{
+			cOneBookmark = cBookmarksList[i];
+			if (*cOneBookmark == '\0' || *cOneBookmark == '#')
+				continue;
+			
+			str = strchr (cOneBookmark, ' ');
+			if ((str && strncmp (cOneBookmark, cURI, str - cOneBookmark) == 0) || (!str && strcmp (cOneBookmark, cURI) == 0))
+			{
+				cBookmarksList[i] = g_strdup_printf ("%s %s", cURI, cName);
+				g_free (cOneBookmark);
+				break;
+			}
+		}
+		
+		if (cBookmarksList[i] == NULL)
+		{
+			cd_warning ("bookmark '%s' not found", cURI);
+		}
+		else
+		{
+			cContent = g_strjoinv ("\n", cBookmarksList);
+			g_file_set_contents (myData.cBookmarksURI, cContent, -1, &erreur);
+			if (erreur != NULL)
+			{
+				cd_warning ("while trying to write bookmarks file : %s", erreur->message);
+				g_error_free (erreur);
+			}
+			g_free (cContent);
+		}
+		g_strfreev (cBookmarksList);
+	}
+}
+
+void cd_shortcuts_add_one_bookmark (const gchar *cURI, GldiModuleInstance *myApplet)
+{
+	g_return_if_fail (cURI != NULL);
+	cd_message ("%s (%s)", __func__, cURI);
+	
+	// see if we need to add a new line before the new URI.
+	gchar *cContent = NULL;
+	gsize length = 0;
+	g_file_get_contents (myData.cBookmarksURI,
+		&cContent,
+		&length,
+		NULL);
+	gboolean bAddNewLine = (cContent && length > 0 && cContent[length-1] != '\n');
+	g_free (cContent);
+	
+	// append the new URI to the file.
+	FILE *f = fopen (myData.cBookmarksURI, "a");
+	if (f != NULL)
+	{
+		gchar *cNewLine = g_strdup_printf ("%s%s\n", bAddNewLine ? "\n" : "", cURI);
+		fputs(cNewLine, f);
+		g_free (cNewLine);
+		fclose (f);
+	}
+}
+
 GList *cd_shortcuts_list_bookmarks (gchar *cBookmarkFilePath, GldiModuleInstance *myApplet)
 {
 	GList *pBookmarkIconList = NULL;
@@ -407,7 +424,8 @@ GList *cd_shortcuts_list_bookmarks (gchar *cBookmarkFilePath, GldiModuleInstance
 	{
 		_init_disk_usage (pNewIcon, myApplet);
 		CDDiskUsage *pDiskUsage = CD_APPLET_GET_MY_ICON_DATA (pNewIcon);
-		if (pDiskUsage) pDiskUsage->iLastCheckTime = 1e9;  // so that this bookmark will never be considered old, and therefore removed.
+		if (pDiskUsage) // so that this bookmark will never be considered old, and therefore removed.
+			pDiskUsage->iLastCheckTime = 1e9;
 		pBookmarkIconList = g_list_append (pBookmarkIconList, pNewIcon);
 	}
 
@@ -417,7 +435,7 @@ GList *cd_shortcuts_list_bookmarks (gchar *cBookmarkFilePath, GldiModuleInstance
 	g_file_get_contents  (cBookmarkFilePath, &cContent, &length, &erreur);
 	if (erreur != NULL)
 	{
-		cd_warning ("Attention : %s\n  no bookmark will be available", erreur->message);
+		cd_warning ("Attention: %s\n  no bookmark will be available", erreur->message);
 		g_error_free (erreur);
 	}
 	else
@@ -425,27 +443,12 @@ GList *cd_shortcuts_list_bookmarks (gchar *cBookmarkFilePath, GldiModuleInstance
 		gchar **cBookmarksList = g_strsplit (cContent, "\n", -1);
 		g_free (cContent);
 		
-		gchar *cOneBookmark, *cUserName;
+		gchar *cOneBookmark;
+		const gchar *cUserName;
 		int i = 0;
 		for (i = 0; cBookmarksList[i] != NULL; i ++)
 		{
-			cOneBookmark = cBookmarksList[i];
-			cUserName = NULL;
-			if (cOneBookmark != NULL && *cOneBookmark == '/')  // ne devrait pas arriver si on ajoute les signets via le dock ou Nautilus.
-			{
-				gchar *tmp = g_strconcat ("file://", cOneBookmark, NULL);  // sinon launch_uri() ne marche pas sous Gnome.
-				g_free (cOneBookmark);
-				cOneBookmark = tmp;
-			}
-			else  // c'est une URI valide, on regarde si il y'a un nom utilisateur.
-			{
-				gchar *str = strchr (cOneBookmark, ' ');  // pas d'espace dans une URI, donc le 1er espace signifie la separation entre URI et nom utilisateur.
-				if (str != NULL)
-				{
-					cUserName = str + 1;
-					*str = '\0';
-				}
-			}
+			cUserName = _get_custom_name_and_uri (cBookmarksList[i], &cOneBookmark);
 			if (*cOneBookmark != '\0' && *cOneBookmark != '#')
 			{
 				cd_message (" + 1 bookmark : %s", cOneBookmark);
