@@ -26,10 +26,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <signal.h>
-#include <gdk/gdkkeysyms.h>
-// gdk.h semble necessaire pour certains
 #include <gdk/gdk.h>
-#include <gdk/gdkx.h>
 
 #include <vte/vte.h>
 
@@ -38,10 +35,6 @@
 #include "terminal-menu-functions.h"
 #include "terminal-widget.h"
 
-#if (GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 20)
-#include <gdk/gdkkeysyms-compat.h>
-#endif
-
 void cd_terminal_grab_focus (void)
 {
 	int iCurrentNumPage = gtk_notebook_get_current_page (GTK_NOTEBOOK(myData.tab));
@@ -51,12 +44,14 @@ void cd_terminal_grab_focus (void)
 
 CairoDialog *cd_terminal_build_dialog (void)
 {
-	CairoDialogAttribute attr;
-	memset (&attr, 0, sizeof (CairoDialogAttribute));
+	CairoDialogAttr attr;
+	memset (&attr, 0, sizeof (CairoDialogAttr));
 	attr.cText = D_("Terminal");
 	attr.pInteractiveWidget = myData.tab;
 	attr.bHideOnClick = TRUE;  // keep the dialog alive on click (hide it).
-	return cairo_dock_build_dialog (&attr, myIcon, myContainer);
+	attr.pIcon = myIcon;
+	attr.pContainer = myContainer;
+	return gldi_dialog_new (&attr);
 }
 
 void term_on_keybinding_pull(const char *keystring, gpointer user_data)
@@ -65,39 +60,26 @@ void term_on_keybinding_pull(const char *keystring, gpointer user_data)
 	{
 		if (myDesklet)
 		{
-			gboolean bHasFocus = (gtk_window_has_toplevel_focus (GTK_WINDOW (myDesklet->container.pWidget)) || gtk_widget_has_focus (myData.tab) || gtk_widget_has_focus (myDesklet->container.pWidget));
-			if (! bHasFocus)
-			{
-				GtkWidget *vterm;
-				int i, iNbPages = gtk_notebook_get_n_pages (GTK_NOTEBOOK (myData.tab));
-				for (i = 0; i < iNbPages && ! bHasFocus; ++i)
-				{
-					vterm = gtk_notebook_get_nth_page(GTK_NOTEBOOK(myData.tab), i);
-					bHasFocus = gtk_widget_has_focus (vterm);
-				}
-				bHasFocus |= (gldi_container_get_Xid (myContainer) == cairo_dock_get_current_active_window ());
-			}
-			cd_debug ("%s (%d)", __func__, bHasFocus);
-			
+			gboolean bHasFocus = gldi_container_is_active (myContainer);
 			if (bHasFocus)
 			{
-				cairo_dock_hide_desklet(myDesklet);
+				gldi_desklet_hide (myDesklet);
 			}
 			else
 			{
-				cairo_dock_show_desklet (myDesklet);
-				
+				gldi_desklet_show (myDesklet);
+				cd_terminal_grab_focus ();
 			}
 		}
 		else if (myData.dialog)
 		{
 			if (gldi_container_is_visible (CAIRO_CONTAINER (myData.dialog)))
 			{
-				cairo_dock_hide_dialog (myData.dialog);
+				gldi_dialog_hide (myData.dialog);
 			}
 			else
 			{
-				cairo_dock_unhide_dialog (myData.dialog);
+				gldi_dialog_unhide (myData.dialog);
 				cd_terminal_grab_focus ();
 			}
 		}
@@ -108,11 +90,7 @@ void term_on_keybinding_pull(const char *keystring, gpointer user_data)
 	}
 }
 
-#if GTK_CHECK_VERSION (3, 4, 0)
 static gchar *_get_label_and_color (const gchar *cLabel, GdkRGBA *pColor, gboolean *bColorSet)
-#else
-static gchar *_get_label_and_color (const gchar *cLabel, GdkColor *pColor, gboolean *bColorSet)
-#endif
 {
 	gchar *cUsefulLabel;
 	gchar *str = strchr (cLabel, '>');
@@ -123,11 +101,7 @@ static gchar *_get_label_and_color (const gchar *cLabel, GdkColor *pColor, gbool
 		if (col_end)
 		{
 			gchar *cColor = g_strndup (col, col_end - col);
-			#if GTK_CHECK_VERSION (3, 4, 0)
 			*bColorSet = gdk_rgba_parse (pColor, cColor);
-			#else
-			*bColorSet = gdk_color_parse (cColor, pColor);
-			#endif
 			g_free (cColor);
 		}
 		cUsefulLabel = g_strdup (str+1);
@@ -152,18 +126,10 @@ static void _on_got_tab_name (int iClickedButton, GtkWidget *pInteractiveWidget,
 		if (cNewName != NULL)
 		{
 			GtkLabel *pLabel = data[0];
-			#if GTK_CHECK_VERSION (3, 4, 0)
 			GdkRGBA *pColor = data[1];
-			#else
-			GdkColor *pColor = data[1];
-			#endif
 			if (pColor)
 			{
-				#if GTK_CHECK_VERSION (3, 4, 0)
 				gchar *cColor = gdk_rgba_to_string (pColor);
-				#else
-				gchar *cColor = gdk_color_to_string (pColor);
-				#endif
 				gchar *cNewColoredName = g_strdup_printf ("<span color='%s'>%s</span>", cColor, cNewName);
 				gtk_label_set_markup (pLabel, cNewColoredName);
 				g_free (cNewColoredName);
@@ -196,11 +162,7 @@ void terminal_rename_tab (GtkWidget *vterm)
 	{
 		GtkLabel *pLabel = pTabWidgetList->data;
 		const gchar *cCurrentName = gtk_label_get_label (pLabel);
-		#if GTK_CHECK_VERSION (3, 4, 0)
 		GdkRGBA *pColor = g_new0 (GdkRGBA, 1);
-		#else
-		GdkColor *pColor = g_new0 (GdkColor, 1);
-		#endif
 		gboolean bColorSet = FALSE;
 		gchar *cUsefulLabel = _get_label_and_color (cCurrentName, pColor, &bColorSet);
 		if (!bColorSet)
@@ -212,7 +174,7 @@ void terminal_rename_tab (GtkWidget *vterm)
 		gpointer *data = g_new (gpointer, 2);
 		data[0] = pLabel;
 		data[1] = pColor;
-		cairo_dock_show_dialog_with_entry (D_("Set title for this tab:"),
+		gldi_dialog_show_with_entry (D_("Set title for this tab:"),
 			myIcon, myContainer, "same icon",  /// NULL, (myDock ? CAIRO_CONTAINER (myData.dialog) : CAIRO_CONTAINER (myDesklet))
 			cUsefulLabel,
 			(CairoDockActionOnAnswerFunc)_on_got_tab_name, data, (GFreeFunc)_free_rename_data);
@@ -221,7 +183,6 @@ void terminal_rename_tab (GtkWidget *vterm)
 	}
 }
 
-#if GTK_CHECK_VERSION (3, 4, 0) // now we have a GtkColorChooserDialog which impliments GtkColorChooser
 static void _set_color (GtkDialog *pColorSelection, gint iAnswer, GtkLabel *pLabel)
 {
 	if (iAnswer != GTK_RESPONSE_OK)
@@ -238,14 +199,7 @@ static void _set_color (GtkDialog *pColorSelection, gint iAnswer, GtkLabel *pLab
 		(guint) (color.red * 65535),
 		(guint) (color.green * 65535),
 		(guint) (color.blue * 65535));
-#else
-static void _set_color (GtkColorSelection *pColorSelection, GtkLabel *pLabel)
-{
-	GdkColor color;
-	gtk_color_selection_get_current_color (pColorSelection, &color);
-	gchar *cColor = gdk_color_to_string (&color);
-#endif
-	
+
 	const gchar *cCurrentLabel = gtk_label_get_text (pLabel);  // recupere le texte sans les balises pango.
 	//gchar *cUsefulLabel = _get_label_and_color (cCurrentLabel, NULL, NULL);
 	gchar *cNewLabel = g_strdup_printf ("<span color='%s'>%s</span>", cColor, cCurrentLabel);
@@ -268,45 +222,22 @@ void terminal_change_color_tab (GtkWidget *vterm)
 	if (pTabWidgetList != NULL && pTabWidgetList->data != NULL)
 	{
 		GtkLabel *pLabel = pTabWidgetList->data;
-		
-		#if GTK_CHECK_VERSION (3, 4, 0)
+
 		GtkWidget *pColorDialog = gtk_color_chooser_dialog_new (D_("Select a color"), NULL);
-		#else
-		GtkWidget *pColorDialog = gtk_color_selection_dialog_new (D_("Select a color"));
-		GtkWidget *colorsel = gtk_color_selection_dialog_get_color_selection ((GtkColorSelectionDialog *) pColorDialog);
-		#endif
 
 		const gchar *cCurrentLabel = gtk_label_get_text (pLabel);
-		#if GTK_CHECK_VERSION (3, 4, 0)
 		GdkRGBA color;
-		#else
-		GdkColor color;
-		#endif
 		gboolean bColorSet = FALSE;
 		gchar *cUsefulLabel = _get_label_and_color (cCurrentLabel, &color, &bColorSet);
 		g_free (cUsefulLabel);
 		if (bColorSet)
 		{
-			#if GTK_CHECK_VERSION (3, 4, 0)
 			gtk_color_chooser_set_rgba (GTK_COLOR_CHOOSER (pColorDialog), &color);
-			#else
-			gtk_color_selection_set_current_color (GTK_COLOR_SELECTION (colorsel), &color);
-			#endif
 		}
 
-		#if GTK_CHECK_VERSION (3, 4, 0)
 		gtk_color_chooser_set_use_alpha (GTK_COLOR_CHOOSER (pColorDialog), FALSE);
 		g_signal_connect (pColorDialog, "response", G_CALLBACK (_set_color), pLabel);
-		#else
-		gtk_color_selection_set_has_opacity_control (GTK_COLOR_SELECTION (colorsel), FALSE);
-		g_signal_connect (colorsel, "color-changed", G_CALLBACK (_set_color), pLabel);
-		#endif
-		#if (GTK_MAJOR_VERSION < 3)
-		gtk_widget_hide (((GtkColorSelectionDialog *) pColorDialog)->cancel_button);
-		gtk_widget_hide (((GtkColorSelectionDialog *) pColorDialog)->help_button);
-		g_signal_connect_swapped (((GtkColorSelectionDialog *) pColorDialog)->ok_button, "clicked", G_CALLBACK (gtk_widget_destroy), pColorDialog);
-		#endif
-		
+
 		gtk_window_present (GTK_WINDOW (pColorDialog));
 	}
 }
@@ -328,29 +259,43 @@ void terminal_close_tab (GtkWidget *vterm)
 	}
 }
 
-
 static void _term_apply_settings_on_vterm(GtkWidget *vterm)
 {
 	g_return_if_fail (vterm != NULL);
-	vte_terminal_set_colors(VTE_TERMINAL(vterm), &myConfig.forecolor, &myConfig.backcolor, NULL, 0);
-	#if (GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION >= 12)
-	vte_terminal_set_opacity(VTE_TERMINAL(vterm), myConfig.transparency);
+
+	#if VTE_CHECK_VERSION(2,91,0)
+	vte_terminal_set_colors (VTE_TERMINAL(vterm), &myConfig.forecolor.rgba, &myConfig.backcolor.rgba, NULL, 0);
+	#else
+	vte_terminal_set_colors_rgba (VTE_TERMINAL(vterm), &myConfig.forecolor.rgba, &myConfig.backcolor.rgba, NULL, 0);
 	#endif
-	
+
+	if (myConfig.bCustomFont)
+	{
+		#if VTE_CHECK_VERSION(2,91,0)
+		PangoFontDescription *fd = pango_font_description_from_string(myConfig.cCustomFont);
+		vte_terminal_set_font (VTE_TERMINAL (vterm), fd);
+		#else
+		vte_terminal_set_font_from_string (VTE_TERMINAL (vterm), myConfig.cCustomFont);
+		#endif
+	}
+	else
+		vte_terminal_set_font (VTE_TERMINAL (vterm), NULL);
+
+	vte_terminal_set_scroll_on_output (VTE_TERMINAL (vterm), myConfig.bScrollOutput);
+	vte_terminal_set_scroll_on_keystroke (VTE_TERMINAL (vterm), myConfig.bScrollKeystroke);
+	if (myConfig.bScrollback)
+		vte_terminal_set_scrollback_lines (VTE_TERMINAL (vterm), myConfig.iScrollback);
+	else
+		vte_terminal_set_scrollback_lines (VTE_TERMINAL (vterm), -1); // -1 <=> infinite
+
 	if (myDock)
 	{
 		// since dialogs can't be resized (like desklets), set the size as defined in the config.
 		// Note: vte_terminal_set_size() doesn't work since the port to GTK3.
-		#ifdef LIBVTE_IS_NOT_BUGGY
-		g_object_set (vterm, "width-request", 0, NULL);  // reset if ever it was previously set (removing this line doesn't make vte_terminal_set_size() work ...)
-		g_object_set (vterm, "height-request", 0, NULL);
-		vte_terminal_set_size(VTE_TERMINAL(vterm), myConfig.iNbColumns, myConfig.iNbRows);
-		#else
 		g_object_set (vterm,
 			"width-request", myConfig.iNbColumns * vte_terminal_get_char_width (VTE_TERMINAL(vterm)),
 			"height-request", myConfig.iNbRows * vte_terminal_get_char_height (VTE_TERMINAL(vterm)),
 			NULL);
-		#endif
 	}
 	else
 	{
@@ -374,6 +319,52 @@ void term_apply_settings (void)
 	}
 }
 
+static void _create_terminal (GtkWidget *vterm)
+{
+	pid_t pid; 
+	#if (GLIB_MAJOR_VERSION > 2) || (GLIB_MAJOR_VERSION == 2 && GLIB_MINOR_VERSION >= 18)  // VTE_CHECK_VERSION doesn't exist in Hardy.
+		#if VTE_CHECK_VERSION(0,26,0)
+		const gchar *argv[] = {g_getenv ("SHELL"), NULL};
+		#if VTE_CHECK_VERSION(2,91,0)
+		vte_terminal_spawn_sync (
+		#else
+		vte_terminal_fork_command_full (
+		#endif
+			VTE_TERMINAL(vterm),
+			VTE_PTY_NO_LASTLOG | VTE_PTY_NO_UTMP | VTE_PTY_NO_WTMP,
+			"~/",
+			(gchar**)argv,  // argv
+			NULL,  // envv
+			0,  // GSpawnFlags spawn_flags
+			NULL,  // GSpawnChildSetupFunc child_setup
+			NULL,  // gpointer child_setup_data
+			&pid,
+			#if VTE_CHECK_VERSION(2,91,0)
+			NULL, // cancellable
+			#endif
+			NULL);
+		#else
+		pid = vte_terminal_fork_command (VTE_TERMINAL(vterm),
+			NULL,
+			NULL,
+			NULL,
+			"~/",
+			FALSE,
+			FALSE,
+			FALSE);
+		#endif
+	#else
+		pid = vte_terminal_fork_command (VTE_TERMINAL(vterm),
+			NULL,
+			NULL,
+			NULL,
+			"~/",
+			FALSE,
+			FALSE,
+			FALSE);
+	#endif
+}
+
 static void on_terminal_child_exited(VteTerminal *vterm,
                                      gpointer t)
 {
@@ -385,49 +376,16 @@ static void on_terminal_child_exited(VteTerminal *vterm,
 	else {
 		// \r needed to return to the beginning of the line
 		vte_terminal_feed(VTE_TERMINAL(vterm), "Shell exited. Another one is launching...\r\n\n", -1);
-		
-		pid_t pid; 
-		#if (GLIB_MAJOR_VERSION > 2) || (GLIB_MAJOR_VERSION == 2 && GLIB_MINOR_VERSION >= 18)  // VTE_CHECK_VERSION doesn't exist in Hardy.
-			#if VTE_CHECK_VERSION(0,26,0)
-			const gchar *argv[] = {g_getenv ("SHELL"), NULL};
-			vte_terminal_fork_command_full (VTE_TERMINAL(vterm),
-				VTE_PTY_NO_LASTLOG | VTE_PTY_NO_UTMP | VTE_PTY_NO_WTMP,
-				"~/",
-				(gchar**)argv,  // argv
-				NULL,  // envv
-				0,  // GSpawnFlags spawn_flags
-				NULL,  // GSpawnChildSetupFunc child_setup
-				NULL,  // gpointer child_setup_data
-				&pid,
-				NULL);
-			#else
-			pid = vte_terminal_fork_command (VTE_TERMINAL(vterm),
-				NULL,
-				NULL,
-				NULL,
-				"~/",
-				FALSE,
-				FALSE,
-				FALSE);
-			#endif
-		#else
-			pid = vte_terminal_fork_command (VTE_TERMINAL(vterm),
-				NULL,
-				NULL,
-				NULL,
-				"~/",
-				FALSE,
-				FALSE,
-				FALSE);
-		#endif
+		_create_terminal (GTK_WIDGET(vterm));
+
 		if (myData.dialog)
-			cairo_dock_hide_dialog (myData.dialog);
+			gldi_dialog_hide (myData.dialog);
 		else if (myDesklet && myConfig.shortcut)
 		{
-			cairo_dock_hide_desklet (myDesklet);
-			Icon *icon = cairo_dock_get_dialogless_icon ();
+			gldi_desklet_hide (myDesklet);
+			Icon *icon = gldi_icons_get_any_without_dialog ();
 			g_return_if_fail (icon != NULL);
-			cairo_dock_show_temporary_dialog_with_icon_printf (D_("You can recall the Terminal desklet by typing %s"), icon, CAIRO_CONTAINER (g_pMainDock), 3500, MY_APPLET_SHARE_DATA_DIR"/"MY_APPLET_ICON_FILE, myConfig.shortcut);
+			gldi_dialog_show_temporary_with_icon_printf (D_("You can recall the Terminal desklet by typing %s"), icon, CAIRO_CONTAINER (g_pMainDock), 3500, MY_APPLET_SHARE_DATA_DIR"/"MY_APPLET_ICON_FILE, myConfig.shortcut);
 		}
 	}
 }
@@ -442,9 +400,7 @@ static void _terminal_paste (GtkMenuItem *menu_item, GtkWidget *data)
   vte_terminal_paste_clipboard(VTE_TERMINAL(data));
 }
 
-
-
-static void on_new_tab (GtkMenuItem *menu_item, gpointer *data)
+static void on_new_tab (GtkMenuItem *menu_item, G_GNUC_UNUSED gpointer data)
 {
 	terminal_new_tab();
 }
@@ -462,57 +418,32 @@ static void on_close_tab (GtkMenuItem *menu_item, GtkWidget *vterm)
 }
 static GtkWidget *_terminal_build_menu_tab (GtkWidget *vterm)
 {
-	GtkWidget *menu = gtk_menu_new ();
+	GtkWidget *menu = gldi_menu_new (NULL);
 	
-	GtkWidget *menu_item, *image;
+	GtkWidget *menu_item;
 	if (vterm)
 	{
-		menu_item = gtk_image_menu_item_new_with_label (D_("Copy"));
-		image = gtk_image_new_from_stock (GTK_STOCK_COPY, GTK_ICON_SIZE_MENU);
-		_gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item), image);
-		gtk_menu_shell_append  (GTK_MENU_SHELL (menu), menu_item);
-		g_signal_connect (G_OBJECT (menu_item), "activate", G_CALLBACK(_terminal_copy), vterm);
+		gldi_menu_add_item (menu, D_("Copy"), GLDI_ICON_NAME_COPY, G_CALLBACK(_terminal_copy), vterm);
 		
-		menu_item = gtk_image_menu_item_new_with_label (D_("Paste"));
-		image = gtk_image_new_from_stock (GTK_STOCK_PASTE, GTK_ICON_SIZE_MENU);
-		_gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item), image);
-		gtk_menu_shell_append  (GTK_MENU_SHELL (menu), menu_item);
-		g_signal_connect (G_OBJECT (menu_item), "activate", G_CALLBACK(_terminal_paste), vterm);
+		gldi_menu_add_item (menu, D_("Paste"), GLDI_ICON_NAME_PASTE, G_CALLBACK(_terminal_paste), vterm);
 		
 		menu_item = gtk_separator_menu_item_new ();
-		gtk_menu_shell_append  (GTK_MENU_SHELL (menu), menu_item);
+		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
 	}
-
-  menu_item = gtk_image_menu_item_new_with_label (D_("New Tab"));
-  image = gtk_image_new_from_stock (GTK_STOCK_NEW, GTK_ICON_SIZE_MENU);
-  _gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item), image);
-  gtk_menu_shell_append  (GTK_MENU_SHELL (menu), menu_item);
-  g_signal_connect (G_OBJECT (menu_item), "activate", G_CALLBACK(on_new_tab), vterm);
-  
-  menu_item = gtk_image_menu_item_new_with_label (D_("Rename this Tab"));
-  image = gtk_image_new_from_stock (GTK_STOCK_EDIT, GTK_ICON_SIZE_MENU);
-  _gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item), image);
-  gtk_menu_shell_append  (GTK_MENU_SHELL (menu), menu_item);
-  g_signal_connect (G_OBJECT (menu_item), "activate", G_CALLBACK(on_rename_tab), vterm);
-
-  menu_item = gtk_image_menu_item_new_with_label (D_("Change this Tab's colour"));
-  image = gtk_image_new_from_stock (GTK_STOCK_COLOR_PICKER, GTK_ICON_SIZE_MENU);
-  _gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item), image);
-  gtk_menu_shell_append  (GTK_MENU_SHELL (menu), menu_item);
-  g_signal_connect (G_OBJECT (menu_item), "activate", G_CALLBACK(on_change_tab_color), vterm);
-
-  menu_item = gtk_image_menu_item_new_with_label (D_("Close this Tab"));
-  image = gtk_image_new_from_stock (GTK_STOCK_CLOSE, GTK_ICON_SIZE_MENU);
-  _gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item), image);
-  gtk_menu_shell_append  (GTK_MENU_SHELL (menu), menu_item);
-  g_signal_connect (G_OBJECT (menu_item), "activate", G_CALLBACK(on_close_tab), vterm);
-
-  return menu;
+	
+	gldi_menu_add_item (menu, D_("New Tab"), GLDI_ICON_NAME_NEW, G_CALLBACK(on_new_tab), NULL);
+	
+	gldi_menu_add_item (menu, D_("Rename this Tab"), GLDI_ICON_NAME_EDIT, G_CALLBACK(on_rename_tab), vterm);
+	
+	gldi_menu_add_item (menu, D_("Change this Tab's colour"), GLDI_ICON_NAME_SELECT_COLOR, G_CALLBACK(on_change_tab_color), vterm);
+	
+	gldi_menu_add_item (menu, D_("Close this Tab"), GLDI_ICON_NAME_CLOSE, G_CALLBACK(on_close_tab), vterm);
+	
+	return menu;
 }
 
 static gboolean applet_on_terminal_press_cb(GtkWidget *vterm, GdkEventButton *event, gpointer user_data)
 {
-	cd_debug ("%s ()", __func__);
 	if (event->button == 3)
 	{
 		GtkWidget *menu = _terminal_build_menu_tab (vterm);
@@ -527,6 +458,7 @@ static gboolean applet_on_terminal_press_cb(GtkWidget *vterm, GdkEventButton *ev
 			1,
 			gtk_get_current_event_time ());
 	}
+	gtk_window_present (GTK_WINDOW (myContainer->pWidget));
 	return FALSE;
 }
 static void applet_on_terminal_eof(VteTerminal *vterm,
@@ -566,31 +498,43 @@ static gboolean on_key_press_term (GtkWidget *pWidget,
 	gboolean bIntercept = FALSE;
 	if (pKey->type == GDK_KEY_PRESS && (pKey->state & GDK_CONTROL_MASK))
 	{
+		bIntercept = TRUE;
 		switch (pKey->keyval)
 		{
-			case GDK_t :
+			case GDK_KEY_t :
+			case GDK_KEY_T : // with Shift -> Gnome-Terminal
 				terminal_new_tab();
-				bIntercept = TRUE;
 			break ;
-			case GDK_w :
+			case GDK_KEY_w :
+			case GDK_KEY_W : // with Shift
 				terminal_close_tab (NULL);
-				bIntercept = TRUE;
 			break ;
-			case GDK_Page_Down :
+			case GDK_KEY_C :
+				if (pKey->state & GDK_SHIFT_MASK)
+					_terminal_copy (NULL, pWidget);
+				else
+					bIntercept = FALSE;
+			break ;
+			case GDK_KEY_V :
+				if (pKey->state & GDK_SHIFT_MASK)
+					_terminal_paste (NULL, pWidget);
+				else
+					bIntercept = FALSE;
+			break ;
+			case GDK_KEY_Page_Down :
 				if (pKey->state & GDK_SHIFT_MASK)
 					_terminal_move_tab (+1);
 				else
 					_terminal_switch_tab (+1);
-				bIntercept = TRUE;
 			break ;
-			case GDK_Page_Up :
+			case GDK_KEY_Page_Up :
 				if (pKey->state & GDK_SHIFT_MASK)
 					_terminal_move_tab (-1);
 				else
 					_terminal_switch_tab (-1);
-				bIntercept = TRUE;
 			break ;
 			default :
+				bIntercept = FALSE;
 			break ;
 		}
 	}
@@ -621,41 +565,12 @@ void terminal_new_tab(void)
 	//\_________________ On cree un nouveau terminal.
 	GtkWidget *vterm = vte_terminal_new();
 	GTK_WIDGET_GET_CLASS (vterm)->get_accessible = _get_dummy_accessible;  // this is to prevent a bug in libvet2.90; it gives a warning, but it's better than a crash !
+	#if ! VTE_CHECK_VERSION(2,91,0)
 	vte_terminal_set_emulation (VTE_TERMINAL(vterm), "xterm");
-	pid_t pid; 
-	#if (GLIB_MAJOR_VERSION > 2) || (GLIB_MAJOR_VERSION == 2 && GLIB_MINOR_VERSION >= 18)  // VTE_CHECK_VERSION doesn't exist in Hardy.
-		#if VTE_CHECK_VERSION(0,26,0)
-		const gchar *argv[] = {g_getenv ("SHELL"), NULL};
-		vte_terminal_fork_command_full (VTE_TERMINAL(vterm),
-			VTE_PTY_NO_LASTLOG | VTE_PTY_NO_UTMP | VTE_PTY_NO_WTMP,
-			"~/",
-			(gchar**)argv,  // argv
-			NULL,  // envv
-			0,  // GSpawnFlags spawn_flags
-			NULL,  // GSpawnChildSetupFunc child_setup
-			NULL,  // gpointer child_setup_data
-			&pid,
-			NULL);
-		#else
-		pid = vte_terminal_fork_command (VTE_TERMINAL(vterm),
-			NULL,
-			NULL,
-			NULL,
-			"~/",
-			FALSE,
-			FALSE,
-			FALSE);
-		#endif
-	#else
-		pid = vte_terminal_fork_command (VTE_TERMINAL(vterm),
-			NULL,
-			NULL,
-			NULL,
-			"~/",
-			FALSE,
-			FALSE,
-			FALSE);
 	#endif
+
+	_create_terminal (vterm);
+
 	g_signal_connect (G_OBJECT (vterm), "child-exited",
 				G_CALLBACK (on_terminal_child_exited), NULL);
 	g_signal_connect (G_OBJECT (vterm), "button-release-event",
@@ -669,7 +584,7 @@ void terminal_new_tab(void)
 	
 	cairo_dock_allow_widget_to_receive_data (vterm, G_CALLBACK (on_terminal_drag_data_received), NULL);
 
-	GtkWidget *pHBox = _gtk_hbox_new (0);
+	GtkWidget *pHBox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 
 	//\_________________ On choisit un nom qui ne soit pas deja present, de la forme " # n ".
 	int i, iNbPages = gtk_notebook_get_n_pages (GTK_NOTEBOOK(myData.tab));
@@ -773,11 +688,7 @@ static GtkWidget * _terminal_find_clicked_tab_child (int x, int y)  // x,y relat
 	int iCurrentNumPage = gtk_notebook_get_current_page (GTK_NOTEBOOK (myData.tab));
 	pPageChild = gtk_notebook_get_nth_page(GTK_NOTEBOOK(myData.tab), iCurrentNumPage);
 	pTabLabelWidget = gtk_notebook_get_tab_label (GTK_NOTEBOOK(myData.tab), pPageChild);
-	#if (GTK_MAJOR_VERSION < 3)
-	gtk_widget_get_child_requisition (pTabLabelWidget, &requisition);
-	#else
 	gtk_widget_get_preferred_size (pTabLabelWidget, &requisition, NULL);
-	#endif
 	iMaxTabHeight = requisition.height;
 	//g_print ("iMaxTabHeight : %d\n", iMaxTabHeight);
 	
@@ -787,11 +698,7 @@ static GtkWidget * _terminal_find_clicked_tab_child (int x, int y)  // x,y relat
 	{
 		pPageChild = gtk_notebook_get_nth_page(GTK_NOTEBOOK(myData.tab), i);
 		pTabLabelWidget = gtk_notebook_get_tab_label (GTK_NOTEBOOK(myData.tab), pPageChild);
-		#if (GTK_MAJOR_VERSION < 3)
-		gtk_widget_get_child_requisition (pTabLabelWidget, &requisition);
-		#else
 		gtk_widget_get_preferred_size (pTabLabelWidget, &requisition, NULL);
-		#endif
 		gtk_widget_translate_coordinates (myData.tab,
 			pTabLabelWidget,
 			x, y,
@@ -893,7 +800,7 @@ void terminal_build_and_show_tab (void)
 	}
 	else
 	{
-		cairo_dock_add_interactive_widget_to_desklet (myData.tab, myDesklet);
+		gldi_desklet_add_interactive_widget (myDesklet, myData.tab);
 		CD_APPLET_SET_DESKLET_RENDERER (NULL);  // pour empecher le clignotement du au double-buffer.
 	}
 }
