@@ -39,14 +39,14 @@ CD_APPLET_ON_CLICK_BEGIN
 			g_source_remove (myData.iSidPopupDialog);
 			myData.iSidPopupDialog = 0;
 		}
-		cairo_dock_remove_dialog_if_any (pClickedIcon);
+		gldi_dialogs_remove_on_icon (pClickedIcon);
 	}
 	else if (pClickedIcon == myIcon && ! myData.bIsRunning)  // possible si on l'a quitte apres le demarrage de l'applet.
 	{
 		cd_notes_run_manager ();
 	}
 	else
-		CD_APPLET_LEAVE (CAIRO_DOCK_LET_PASS_NOTIFICATION);
+		CD_APPLET_LEAVE (GLDI_NOTIFICATION_LET_PASS);
 CD_APPLET_ON_CLICK_END
 
 
@@ -83,7 +83,7 @@ static void _cd_tomboy_create_new_note (void)
 	}
 	else
 	{
-		cairo_dock_show_dialog_with_entry (D_("Note name : "),
+		gldi_dialog_show_with_entry (D_("Note name : "),
 			myIcon, myContainer,
 			"same icon",
 			NULL,
@@ -111,7 +111,7 @@ static void _cd_tomboy_delete_note (GtkMenuItem *menu_item, Icon *pIcon)
 	if (myConfig.bAskBeforeDelete)
 	{
 		gchar *cQuestion = g_strdup_printf ("%s (%s)", D_("Delete this note?"), pIcon->cName);
-		cairo_dock_show_dialog_with_question (cQuestion,
+		gldi_dialog_show_with_question (cQuestion,
 			pIcon, myDock ? CAIRO_CONTAINER (myIcon->pSubDock) : myContainer,
 			"same icon",
 			(CairoDockActionOnAnswerFunc) _on_answer_delete,
@@ -150,7 +150,7 @@ static void _on_active_search (int iClickedButton, GtkWidget *pInteractiveWidget
 }
 static void _cd_tomboy_search_for_content (GtkMenuItem *menu_item, gpointer data)
 {
-	cairo_dock_show_dialog_with_entry (D_("Search for:"),
+	gldi_dialog_show_with_entry (D_("Search for:"),
 		myIcon,	myContainer,
 		"same icon",
 		NULL,
@@ -175,7 +175,7 @@ static void _on_active_search_tag (int iClickedButton, GtkWidget *pInteractiveWi
 }
 static void _cd_tomboy_search_for_tag (GtkMenuItem *menu_item, gpointer data)
 {
-	cairo_dock_show_dialog_with_entry (D_("Search for tag:"),
+	gldi_dialog_show_with_entry (D_("Search for tag:"),
 		myIcon,	myContainer,
 		"same icon",
 		NULL,
@@ -215,19 +215,19 @@ CD_APPLET_ON_BUILD_MENU_BEGIN
 	gboolean bClickOnNotes = (pClickedIcon !=  myIcon);
 	
 	gchar *cLabel = g_strdup_printf ("%s (%s)", D_("Add a note"), D_("middle-click"));
-	CD_APPLET_ADD_IN_MENU_WITH_STOCK (cLabel, GTK_STOCK_ADD, _cd_tomboy_add_note, CD_APPLET_MY_MENU);
+	CD_APPLET_ADD_IN_MENU_WITH_STOCK (cLabel, GLDI_ICON_NAME_ADD, _cd_tomboy_add_note, CD_APPLET_MY_MENU);
 	g_free (cLabel);
 	
 	if (bClickOnNotes && pClickedIcon != NULL)
 	{
-		CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (D_("Delete this note"), GTK_STOCK_REMOVE, _cd_tomboy_delete_note, CD_APPLET_MY_MENU, pClickedIcon);
+		CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (D_("Delete this note"), GLDI_ICON_NAME_REMOVE, _cd_tomboy_delete_note, CD_APPLET_MY_MENU, pClickedIcon);
 	}
 	
-	CD_APPLET_ADD_IN_MENU_WITH_STOCK (D_("Reload notes"), GTK_STOCK_REFRESH, _cd_tomboy_reload_notes, CD_APPLET_MY_MENU);
+	CD_APPLET_ADD_IN_MENU_WITH_STOCK (D_("Reload notes"), GLDI_ICON_NAME_REFRESH, _cd_tomboy_reload_notes, CD_APPLET_MY_MENU);
 	
 	CD_APPLET_ADD_SEPARATOR_IN_MENU (CD_APPLET_MY_MENU);
 	
-	CD_APPLET_ADD_IN_MENU_WITH_STOCK  (D_("Search"), GTK_STOCK_FIND, _cd_tomboy_search_for_content, CD_APPLET_MY_MENU);
+	CD_APPLET_ADD_IN_MENU_WITH_STOCK  (D_("Search"), GLDI_ICON_NAME_FIND, _cd_tomboy_search_for_content, CD_APPLET_MY_MENU);
 	CD_APPLET_ADD_IN_MENU(D_("Search for tag"), _cd_tomboy_search_for_tag, CD_APPLET_MY_MENU);
 	
 	CD_APPLET_ADD_IN_MENU(D_("Search for today's note"), _cd_tomboy_search_for_today, CD_APPLET_MY_MENU);
@@ -242,13 +242,13 @@ CD_APPLET_ON_BUILD_MENU_BEGIN
 		icon = ic->data;
 		if (icon->bHasIndicator)
 		{
-			CD_APPLET_ADD_IN_MENU_WITH_STOCK (D_("Reset marks"), GTK_STOCK_CLEAR, _cd_tomboy_reset_marks, CD_APPLET_MY_MENU);
+			CD_APPLET_ADD_IN_MENU_WITH_STOCK (D_("Reset marks"), GLDI_ICON_NAME_CLEAR, _cd_tomboy_reset_marks, CD_APPLET_MY_MENU);
 			break ;
 		}
 	}
 	
 	if (bClickOnNotes && pClickedIcon != NULL)
-		CD_APPLET_LEAVE (CAIRO_DOCK_INTERCEPT_NOTIFICATION);
+		CD_APPLET_LEAVE (GLDI_NOTIFICATION_INTERCEPT);
 CD_APPLET_ON_BUILD_MENU_END
 
 
@@ -268,15 +268,19 @@ CD_APPLET_ON_MIDDLE_CLICK_END
 static gboolean _popup_dialog (Icon *pIcon)
 {
 	CD_APPLET_ENTER;
-	CairoContainer *pContainer = CD_APPLET_MY_ICONS_LIST_CONTAINER;
+	GldiContainer *pContainer = CD_APPLET_MY_ICONS_LIST_CONTAINER;
 	if (pContainer->bInside)
 	{
 		if (g_list_find (CD_APPLET_MY_ICONS_LIST, pIcon))  // on verifie que l'icone ne s'est pas fait effacee entre-temps.
-			cairo_dock_show_temporary_dialog_with_icon (pIcon->cClass,
+		{
+			gchar *cDescription = pIcon->cClass && *pIcon->cClass != '\0' ?
+				pIcon->cClass : D_("No description");
+			gldi_dialog_show_temporary_with_icon (cDescription,
 				pIcon,
 				CD_APPLET_MY_ICONS_LIST_CONTAINER,
 				myConfig.iDialogDuration,
 				myConfig.cIconDefault != NULL ? myConfig.cIconDefault : MY_APPLET_SHARE_DATA_DIR"/"MY_APPLET_ICON_FILE);
+		}
 	}
 	myData.iSidPopupDialog = 0;
 	CD_APPLET_LEAVE (FALSE);
@@ -296,7 +300,7 @@ gboolean cd_tomboy_on_change_icon (gpointer pUserData, Icon *pIcon, CairoDock *p
 	for (ic = pList; ic != NULL; ic = ic->next)
 	{
 		icon = ic->data;
-		cairo_dock_remove_dialog_if_any (icon);
+		gldi_dialogs_remove_on_icon (icon);
 	}
 	
 	if (pIcon && pIcon->bPointed)
@@ -304,10 +308,10 @@ gboolean cd_tomboy_on_change_icon (gpointer pUserData, Icon *pIcon, CairoDock *p
 		myData.iSidPopupDialog = g_timeout_add (500, (GSourceFunc)_popup_dialog, pIcon);
 	}
 	
-	CD_APPLET_LEAVE (CAIRO_DOCK_LET_PASS_NOTIFICATION);
+	CD_APPLET_LEAVE (GLDI_NOTIFICATION_LET_PASS);
 }
 
-gboolean cd_tomboy_on_leave_container (gpointer pUserData, CairoContainer *pContainer, gboolean *bStartAnimation)
+gboolean cd_tomboy_on_leave_container (gpointer pUserData, GldiContainer *pContainer, gboolean *bStartAnimation)
 {
 	CD_APPLET_ENTER;
 	if (myData.iSidPopupDialog != 0)
@@ -322,8 +326,8 @@ gboolean cd_tomboy_on_leave_container (gpointer pUserData, CairoContainer *pCont
 	for (ic = pList; ic != NULL; ic = ic->next)
 	{
 		icon = ic->data;
-		cairo_dock_remove_dialog_if_any (icon);
+		gldi_dialogs_remove_on_icon (icon);
 	}
 	
-	CD_APPLET_LEAVE (CAIRO_DOCK_LET_PASS_NOTIFICATION);
+	CD_APPLET_LEAVE (GLDI_NOTIFICATION_LET_PASS);
 }
